# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: locker.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import uits_pb2 as uits__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='locker.proto',
  package='wireless_android_skyjam',
  syntax='proto2',
  serialized_pb=_b('\n\x0clocker.proto\x12\x17wireless_android_skyjam\x1a\nuits.proto\"\x90\x02\n\x08\x41udioRef\x12\x36\n\x05store\x18\x01 \x02(\x0e\x32\'.wireless_android_skyjam.AudioRef.Store\x12\x0b\n\x03ref\x18\x02 \x02(\x0c\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08\x62it_rate\x18\x05 \x01(\x05\x12\x13\n\x0bsample_rate\x18\x06 \x01(\x05\x12\x14\n\x0c\x64ownloadable\x18\x07 \x01(\x08\x12\x17\n\x0f\x64uration_millis\x18\x08 \x01(\x03\x12\x19\n\x11rematch_timestamp\x18\t \x01(\x03\x12\x1e\n\x16invalid_due_to_wipeout\x18\n \x01(\x08\"!\n\x05Store\x12\r\n\tBLOBSTORE\x10\x01\x12\t\n\x05SM_V2\x10\x02\"\x81\x02\n\x08ImageRef\x12\x36\n\x05store\x18\x01 \x01(\x0e\x32\'.wireless_android_skyjam.ImageRef.Store\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x1e\n\x16invalid_due_to_wipeout\x18\x07 \x01(\x08\x12\x38\n\x06origin\x18\x08 \x01(\x0e\x32(.wireless_android_skyjam.ImageRef.Origin\"\x14\n\x05Store\x12\x0b\n\x07SHOEBOX\x10\x03\"!\n\x06Origin\x12\x0c\n\x08PERSONAL\x10\x01\x12\t\n\x05STORE\x10\x02\"1\n\x12UploadedUitsId3Tag\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"5\n\x12\x41\x64\x64itionalMetadata\x12\x10\n\x08tag_name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\x0c\"\x89\x01\n\x0bTrackExtras\x12H\n\x13\x61\x64\x64itional_metadata\x18\x02 \x03(\x0b\x32+.wireless_android_skyjam.AdditionalMetadata\x12\x12\n\ncandidates\x18\x03 \x03(\t\x12\x1c\n\x14original_sample_rate\x18\x04 \x01(\x05\"\xb1\x13\n\x05Track\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\x03\x12\x1f\n\x17last_modified_timestamp\x18\x04 \x01(\x03\x12\x16\n\x07\x64\x65leted\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0e\n\x06\x61rtist\x18\x07 \x01(\t\x12\x13\n\x0b\x61rtist_hash\x18. \x01(\x03\x12\x10\n\x08\x63omposer\x18\x08 \x01(\t\x12\r\n\x05\x61lbum\x18\t \x01(\t\x12\x14\n\x0c\x61lbum_artist\x18\n \x01(\t\x12\x17\n\x0f\x63\x61nonical_album\x18\x38 \x01(\t\x12\x18\n\x10\x63\x61nonical_artist\x18\x39 \x01(\t\x12\x1d\n\x15\x63\x61nonical_genre_album\x18: \x01(\t\x12\x0c\n\x04year\x18\x0b \x01(\x05\x12\x0f\n\x07\x63omment\x18\x0c \x01(\t\x12\x14\n\x0ctrack_number\x18\r \x01(\x05\x12\r\n\x05genre\x18\x0e \x01(\t\x12\x17\n\x0f\x64uration_millis\x18\x0f \x01(\x03\x12\x18\n\x10\x62\x65\x61ts_per_minute\x18\x10 \x01(\x05\x12\x19\n\x11original_bit_rate\x18, \x01(\x05\x12\x34\n\taudio_ref\x18\x11 \x03(\x0b\x32!.wireless_android_skyjam.AudioRef\x12\x38\n\ralbum_art_ref\x18\x12 \x03(\x0b\x32!.wireless_android_skyjam.ImageRef\x12N\n\x13\x61vailability_status\x18\x13 \x01(\x0e\x32\x31.wireless_android_skyjam.Track.AvailabilityStatus\x12\x12\n\nplay_count\x18\x14 \x01(\x05\x12@\n\x0c\x63ontent_type\x18\x19 \x01(\x0e\x32*.wireless_android_skyjam.Track.ContentType\x12\x19\n\x11total_track_count\x18\x1a \x01(\x05\x12\x13\n\x0b\x64isc_number\x18\x1b \x01(\x05\x12\x18\n\x10total_disc_count\x18\x1c \x01(\x05\x12\x39\n\x08\x63hannels\x18\x1d \x01(\x0e\x32\'.wireless_android_skyjam.Track.Channels\x12<\n\ntrack_type\x18\x1e \x01(\x0e\x32(.wireless_android_skyjam.Track.TrackType\x12\x1e\n\x16use_single_server_copy\x18; \x01(\x08\x12\x35\n\x06rating\x18\x1f \x01(\x0e\x32%.wireless_android_skyjam.Track.Rating\x12\x16\n\x0e\x65stimated_size\x18  \x01(\x03\x12\x10\n\x08store_id\x18! \x01(\t\x12\x12\n\nmetajam_id\x18\" \x01(\t\x12 \n\x15metajam_id_confidence\x18+ \x01(\x01:\x01\x30\x12\x0c\n\x04uits\x18# \x01(\t\x12<\n\ruits_metadata\x18( \x01(\x0b\x32%.wireless_android_skyjam.UitsMetadata\x12\x13\n\x0b\x63ompilation\x18$ \x01(\x08\x12\x19\n\x11\x63lient_date_added\x18% \x01(\x03\x12\x18\n\x10recent_timestamp\x18& \x01(\x03\x12\x1d\n\x0e\x64o_not_rematch\x18\' \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13\x66rom_album_purchase\x18) \x01(\x08\x12\x18\n\x10\x61lbum_metajam_id\x18* \x01(\t\x12\x16\n\x0etransaction_id\x18- \x01(\t\x12\x13\n\x0b\x64\x65\x62ug_track\x18/ \x01(\x08\x12\x18\n\x10normalized_title\x18\x30 \x01(\t\x12\x19\n\x11normalized_artist\x18\x31 \x01(\t\x12\x18\n\x10normalized_album\x18\x32 \x01(\t\x12\x1f\n\x17normalized_album_artist\x18\x33 \x01(\t\x12\"\n\x1anormalized_canonical_album\x18\x36 \x01(\t\x12#\n\x1bnormalized_canonical_artist\x18\x37 \x01(\t\x12\x13\n\x0buploader_id\x18\x34 \x01(\t\x12\x17\n\x0f\x63lient_album_id\x18\x35 \x01(\t\x12\x18\n\x10label_owner_code\x18< \x01(\t\x12I\n\x15original_content_type\x18= \x01(\x0e\x32*.wireless_android_skyjam.Track.ContentType\x12\x42\n\ruploaded_uits\x18G \x03(\x0b\x32+.wireless_android_skyjam.UploadedUitsId3Tag\x12\x42\n\rexplicit_type\x18J \x01(\x0e\x32+.wireless_android_skyjam.Track.ExplicitType\x12:\n\x0ctrack_extras\x18K \x01(\x0b\x32$.wireless_android_skyjam.TrackExtras\"\x86\x01\n\x12\x41vailabilityStatus\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07MATCHED\x10\x02\x12\x14\n\x10UPLOAD_REQUESTED\x10\x03\x12\r\n\tAVAILABLE\x10\x04\x12\x12\n\x0e\x46ORCE_REUPLOAD\x10\x05\x12\x1d\n\x19UPLOAD_PERMANENTLY_FAILED\x10\x06\"W\n\x0b\x43ontentType\x12\x07\n\x03MP3\x10\x01\x12\x07\n\x03M4A\x10\x02\x12\x07\n\x03\x41\x41\x43\x10\x03\x12\x08\n\x04\x46LAC\x10\x04\x12\x07\n\x03OGG\x10\x05\x12\x07\n\x03WMA\x10\x06\x12\x07\n\x03M4P\x10\x07\x12\x08\n\x04\x41LAC\x10\x08\" \n\x08\x43hannels\x12\x08\n\x04MONO\x10\x01\x12\n\n\x06STEREO\x10\x02\"\x8b\x01\n\tTrackType\x12\x11\n\rMATCHED_TRACK\x10\x01\x12\x13\n\x0fUNMATCHED_TRACK\x10\x02\x12\x0f\n\x0bLOCAL_TRACK\x10\x03\x12\x13\n\x0fPURCHASED_TRACK\x10\x04\x12\x1f\n\x1bMETADATA_ONLY_MATCHED_TRACK\x10\x05\x12\x0f\n\x0bPROMO_TRACK\x10\x06\"e\n\x06Rating\x12\r\n\tNOT_RATED\x10\x01\x12\x0c\n\x08ONE_STAR\x10\x02\x12\r\n\tTWO_STARS\x10\x03\x12\x0f\n\x0bTHREE_STARS\x10\x04\x12\x0e\n\nFOUR_STARS\x10\x05\x12\x0e\n\nFIVE_STARS\x10\x06\"3\n\x0c\x45xplicitType\x12\x0c\n\x08\x45XPLICIT\x10\x01\x12\t\n\x05\x43LEAN\x10\x02\x12\n\n\x06\x45\x44ITED\x10\x03\"7\n\x06Tracks\x12-\n\x05track\x18\x01 \x03(\x0b\x32\x1e.wireless_android_skyjam.Track\"\xe4\x02\n\x08Playlist\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\x03\x12\x1f\n\x17last_modified_timestamp\x18\x04 \x01(\x03\x12\x16\n\x07\x64\x65leted\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x45\n\rplaylist_type\x18\x07 \x01(\x0e\x32..wireless_android_skyjam.Playlist.PlaylistType\x12;\n\x10playlist_art_ref\x18\x08 \x01(\x0b\x32!.wireless_android_skyjam.ImageRef\x12\x18\n\x10recent_timestamp\x18\t \x01(\x03\"8\n\x0cPlaylistType\x12\x12\n\x0eUSER_GENERATED\x10\x01\x12\t\n\x05MAGIC\x10\x02\x12\t\n\x05PROMO\x10\x03\"\xde\x03\n\rPlaylistEntry\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\x12\x19\n\x11\x61\x62solute_position\x18\x02 \x01(\x03\x12\x1c\n\x14place_after_entry_id\x18\x03 \x01(\t\x12\x10\n\x08track_id\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x11\n\tclient_id\x18\x06 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x07 \x01(\x03\x12\x1f\n\x17last_modified_timestamp\x18\x08 \x01(\x03\x12\x16\n\x07\x64\x65leted\x18\t \x01(\x08:\x05\x66\x61lse\x12`\n\x19relative_position_id_type\x18\n \x01(\x0e\x32=.wireless_android_skyjam.PlaylistEntry.RelativePositionIdType\x12-\n\x05track\x18\x0f \x01(\x0b\x32\x1e.wireless_android_skyjam.Track\x12\x1d\n\x15place_before_entry_id\x18\x10 \x01(\t\x12\x17\n\x0fstring_position\x18\x11 \x01(\t\"0\n\x16RelativePositionIdType\x12\n\n\x06SERVER\x10\x01\x12\n\n\x06\x43LIENT\x10\x02\"\x80\x04\n\x16TrackSearchRestriction\x12Q\n\tattribute\x18\x01 \x02(\x0e\x32>.wireless_android_skyjam.TrackSearchRestriction.TrackAttribute\x12\r\n\x05value\x18\x02 \x02(\t\x12W\n\x0f\x63omparison_type\x18\x03 \x02(\x0e\x32>.wireless_android_skyjam.TrackSearchRestriction.ComparisonType\"\xa6\x01\n\x0eTrackAttribute\x12\t\n\x05TITLE\x10\x01\x12\n\n\x06\x41RTIST\x10\x02\x12\t\n\x05\x41LBUM\x10\x03\x12\x10\n\x0c\x41LBUM_ARTIST\x10\x04\x12\t\n\x05GENRE\x10\x05\x12\x17\n\x13\x41VAILABILITY_STATUS\x10\x06\x12\x0e\n\nTRACK_TYPE\x10\x07\x12\x08\n\x04YEAR\x10\x08\x12\x0c\n\x08STORE_ID\x10\t\x12\x14\n\x10\x41LBUM_METAJAM_ID\x10\n\"\x81\x01\n\x0e\x43omparisonType\x12\t\n\x05\x45QUAL\x10\x00\x12\r\n\tNOT_EQUAL\x10\x01\x12\x10\n\x0cGREATER_THAN\x10\x02\x12\x11\n\rGREATER_EQUAL\x10\x03\x12\r\n\tLESS_THAN\x10\x04\x12\x0e\n\nLESS_EQUAL\x10\x05\x12\x11\n\rPARTIAL_MATCH\x10\x06\"\xa2\x02\n\x19TrackSearchRestrictionSet\x12S\n\x04type\x18\x01 \x01(\x0e\x32\x45.wireless_android_skyjam.TrackSearchRestrictionSet.RestrictionSetType\x12\x44\n\x0brestriction\x18\x02 \x03(\x0b\x32/.wireless_android_skyjam.TrackSearchRestriction\x12\x43\n\x07sub_set\x18\x03 \x03(\x0b\x32\x32.wireless_android_skyjam.TrackSearchRestrictionSet\"%\n\x12RestrictionSetType\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\"\x98\x02\n\x0eTrackSortOrder\x12I\n\tattribute\x18\x01 \x01(\x0e\x32\x36.wireless_android_skyjam.TrackSortOrder.TrackAttribute\x12\x18\n\ndescending\x18\x02 \x01(\x08:\x04true\"\xa0\x01\n\x0eTrackAttribute\x12\x16\n\x12LAST_MODIFIED_TIME\x10\x01\x12\n\n\x06\x41RTIST\x10\x02\x12\t\n\x05\x41LBUM\x10\x03\x12\t\n\x05TITLE\x10\x04\x12\x10\n\x0cTRACK_NUMBER\x10\x06\x12\x0e\n\nPLAY_COUNT\x10\t\x12\x13\n\x0f\x44URATION_MILLIS\x10\n\x12\n\n\x06RATING\x10\x0b\x12\x11\n\rCREATION_TIME\x10\x0c\"\xde\x03\n\x10GetTracksRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x13\n\x0bupdated_min\x18\x02 \x01(\x03\x12\x17\n\x0finclude_deleted\x18\x03 \x01(\x08\x12\x13\n\x0bmax_results\x18\x04 \x01(\x05\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\t\x12K\n\x12search_restriction\x18\x06 \x03(\x0b\x32/.wireless_android_skyjam.TrackSearchRestriction\x12;\n\nsort_order\x18\x07 \x03(\x0b\x32\'.wireless_android_skyjam.TrackSortOrder\x12K\n\x0frestriction_set\x18\x08 \x01(\x0b\x32\x32.wireless_android_skyjam.TrackSearchRestrictionSet\x12S\n\x10track_projection\x18\t \x01(\x0e\x32\x39.wireless_android_skyjam.GetTracksRequest.TrackProjection\".\n\x0fTrackProjection\x12\x08\n\x04\x46ULL\x10\x01\x12\x11\n\rFRONTEND_VIEW\x10\x02\"\x83\x02\n\x11GetTracksResponse\x12N\n\rresponse_code\x18\x01 \x02(\x0e\x32\x37.wireless_android_skyjam.GetTracksResponse.ResponseCode\x12-\n\x05track\x18\x02 \x03(\x0b\x32\x1e.wireless_android_skyjam.Track\x12\x1f\n\x17\x65stimated_total_results\x18\x03 \x01(\x03\x12\x1a\n\x12\x63ontinuation_token\x18\x04 \x01(\t\"2\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\x10\n\x0cNOT_MODIFIED\x10\x02\x12\x08\n\x04GONE\x10\x03\"\xfc\x01\n\x19GetPlaylistEntriesRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x13\n\x0bupdated_min\x18\x02 \x01(\x03\x12\x17\n\x0finclude_deleted\x18\x03 \x01(\x08\x12\x13\n\x0bmax_results\x18\x04 \x01(\x05\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\t\x12\x1a\n\x12playlist_id_filter\x18\x06 \x01(\t\x12)\n\x1ainclude_all_track_metadata\x18\x07 \x01(\x08:\x05\x66\x61lse\x12(\n\x1aonly_show_available_tracks\x18\x08 \x01(\x08:\x04true\"\xa6\x02\n\x1aGetPlaylistEntriesResponse\x12W\n\rresponse_code\x18\x01 \x02(\x0e\x32@.wireless_android_skyjam.GetPlaylistEntriesResponse.ResponseCode\x12>\n\x0eplaylist_entry\x18\x02 \x03(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\x1f\n\x17\x65stimated_total_results\x18\x03 \x01(\x03\x12\x1a\n\x12\x63ontinuation_token\x18\x04 \x01(\t\"2\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\x10\n\x0cNOT_MODIFIED\x10\x02\x12\x08\n\x04GONE\x10\x03\"\xe0\x01\n\x11PlaylistSortOrder\x12O\n\tattribute\x18\x01 \x01(\x0e\x32<.wireless_android_skyjam.PlaylistSortOrder.PlaylistAttribute\x12\x19\n\ndescending\x18\x02 \x01(\x08:\x05\x66\x61lse\"_\n\x11PlaylistAttribute\x12\x16\n\x12LAST_MODIFIED_TIME\x10\x01\x12\t\n\x05TITLE\x10\x02\x12\x11\n\rCREATION_TIME\x10\x03\x12\x14\n\x10RECENT_TIMESTAMP\x10\x04\"\xc5\x01\n\x13GetPlaylistsRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x13\n\x0bupdated_min\x18\x02 \x01(\x03\x12\x17\n\x0finclude_deleted\x18\x03 \x01(\x08\x12\x13\n\x0bmax_results\x18\x04 \x01(\x05\x12\x1a\n\x12\x63ontinuation_token\x18\x05 \x01(\t\x12>\n\nsort_order\x18\x06 \x01(\x0b\x32*.wireless_android_skyjam.PlaylistSortOrder\"\x8f\x02\n\x14GetPlaylistsResponse\x12Q\n\rresponse_code\x18\x01 \x02(\x0e\x32:.wireless_android_skyjam.GetPlaylistsResponse.ResponseCode\x12\x33\n\x08playlist\x18\x02 \x03(\x0b\x32!.wireless_android_skyjam.Playlist\x12\x1f\n\x17\x65stimated_total_results\x18\x03 \x01(\x03\x12\x1a\n\x12\x63ontinuation_token\x18\x04 \x01(\t\"2\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\x10\n\x0cNOT_MODIFIED\x10\x02\x12\x08\n\x04GONE\x10\x03\"3\n\x12LookupTrackRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\";\n\x1aLookupPlaylistEntryRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\"6\n\x15LookupPlaylistRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\"\x9e\x03\n\x12\x42\x61tchLookupRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12:\n\x05track\x18\x02 \x03(\x0b\x32+.wireless_android_skyjam.LookupTrackRequest\x12@\n\x08playlist\x18\x03 \x03(\x0b\x32..wireless_android_skyjam.LookupPlaylistRequest\x12O\n\rmetadata_type\x18\x04 \x01(\x0e\x32\x38.wireless_android_skyjam.BatchLookupRequest.MetadataType\x12K\n\x0eplaylist_entry\x18\x05 \x03(\x0b\x32\x33.wireless_android_skyjam.LookupPlaylistEntryRequest\x12\x1e\n\x0finclude_deleted\x18\x06 \x01(\x08:\x05\x66\x61lse\";\n\x0cMetadataType\x12\t\n\x05TRACK\x10\x01\x12\x0c\n\x08PLAYLIST\x10\x02\x12\x12\n\x0ePLAYLIST_ENTRY\x10\x03\"\xb9\x01\n\x13\x42\x61tchLookupResponse\x12-\n\x05track\x18\x01 \x03(\x0b\x32\x1e.wireless_android_skyjam.Track\x12\x33\n\x08playlist\x18\x02 \x03(\x0b\x32!.wireless_android_skyjam.Playlist\x12>\n\x0eplaylist_entry\x18\x03 \x03(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\"\xea\x01\n\x12MutateTrackRequest\x12\x34\n\x0c\x63reate_track\x18\x01 \x01(\x0b\x32\x1e.wireless_android_skyjam.Track\x12\x34\n\x0cupdate_track\x18\x02 \x01(\x0b\x32\x1e.wireless_android_skyjam.Track\x12\x14\n\x0c\x64\x65lete_track\x18\x03 \x01(\t\x12\x16\n\x0epartial_update\x18\x04 \x01(\x08\x12\"\n\x14update_last_modified\x18\x05 \x01(\x08:\x04true\x12\x16\n\x0eundelete_track\x18\x06 \x01(\t\"\xe6\x03\n\x0eMutateResponse\x12Q\n\rresponse_code\x18\x01 \x01(\x0e\x32:.wireless_android_skyjam.MutateResponse.MutateResponseCode\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08\x63hild_id\x18\x03 \x03(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12W\n\x13\x61vailability_status\x18\x05 \x01(\x0e\x32:.wireless_android_skyjam.MutateResponse.AvailabilityStatus\x12\x15\n\rerror_message\x18\x06 \x01(\t\"W\n\x12MutateResponseCode\x12\x06\n\x02OK\x10\x01\x12\x0c\n\x08\x43ONFLICT\x10\x02\x12\x13\n\x0fINVALID_REQUEST\x10\x03\x12\x16\n\x12METADATA_TOO_LARGE\x10\x04\"\x86\x01\n\x12\x41vailabilityStatus\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07MATCHED\x10\x02\x12\x14\n\x10UPLOAD_REQUESTED\x10\x03\x12\r\n\tAVAILABLE\x10\x04\x12\x12\n\x0e\x46ORCE_REUPLOAD\x10\x05\x12\x1d\n\x19UPLOAD_PERMANENTLY_FAILED\x10\x06\"\xe5\x01\n\x18\x42\x61tchMutateTracksRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x43\n\x0etrack_mutation\x18\x02 \x03(\x0b\x32+.wireless_android_skyjam.MutateTrackRequest\x12\x1f\n\x11send_notification\x18\x03 \x01(\x08:\x04true\x12\'\n\x19\x64\x65tect_timestamp_conflict\x18\x04 \x01(\x08:\x04true\x12)\n\x1bnotify_fine_grained_updates\x18\x05 \x01(\x08:\x04true\"\xfd\x01\n\x19\x42\x61tchMutateTracksResponse\x12g\n\rresponse_code\x18\x01 \x03(\x0e\x32P.wireless_android_skyjam.BatchMutateTracksResponse.BatchMutateTracksResponseCode\x12@\n\x0fmutate_response\x18\x02 \x03(\x0b\x32\'.wireless_android_skyjam.MutateResponse\"5\n\x1d\x42\x61tchMutateTracksResponseCode\x12\x06\n\x02OK\x10\x01\x12\x0c\n\x08\x43ONFLICT\x10\x02\"\xbf\x02\n\x15MutatePlaylistRequest\x12:\n\x0f\x63reate_playlist\x18\x01 \x01(\x0b\x32!.wireless_android_skyjam.Playlist\x12:\n\x0fupdate_playlist\x18\x02 \x01(\x0b\x32!.wireless_android_skyjam.Playlist\x12\x17\n\x0f\x64\x65lete_playlist\x18\x03 \x01(\t\x12\x16\n\x0epartial_update\x18\x04 \x01(\x08\x12>\n\x0eplaylist_entry\x18\x05 \x03(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\"\n\x14update_last_modified\x18\x06 \x01(\x08:\x04true\x12\x19\n\x11undelete_playlist\x18\x07 \x01(\t\"\xef\x01\n\x1b\x42\x61tchMutatePlaylistsRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12I\n\x11playlist_mutation\x18\x02 \x03(\x0b\x32..wireless_android_skyjam.MutatePlaylistRequest\x12\x1f\n\x11send_notification\x18\x03 \x01(\x08:\x04true\x12\'\n\x19\x64\x65tect_timestamp_conflict\x18\x04 \x01(\x08:\x04true\x12*\n\x1bnotify_fine_grained_updates\x18\x05 \x01(\x08:\x05\x66\x61lse\"\x89\x02\n\x1c\x42\x61tchMutatePlaylistsResponse\x12m\n\rresponse_code\x18\x01 \x03(\x0e\x32V.wireless_android_skyjam.BatchMutatePlaylistsResponse.BatchMutatePlaylistsResponseCode\x12@\n\x0fmutate_response\x18\x02 \x03(\x0b\x32\'.wireless_android_skyjam.MutateResponse\"8\n BatchMutatePlaylistsResponseCode\x12\x06\n\x02OK\x10\x01\x12\x0c\n\x08\x43ONFLICT\x10\x02\"\xb6\x02\n\x1aMutatePlaylistEntryRequest\x12\x45\n\x15\x63reate_playlist_entry\x18\x01 \x01(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\x45\n\x15update_playlist_entry\x18\x02 \x01(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\x45\n\x15\x64\x65lete_playlist_entry\x18\x03 \x01(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\"\n\x14update_last_modified\x18\x04 \x01(\x08:\x04true\x12\x1f\n\x17undelete_playlist_entry\x18\x05 \x01(\t\"\x80\x02\n!BatchMutatePlaylistEntriesRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12T\n\x17playlist_entry_mutation\x18\x02 \x03(\x0b\x32\x33.wireless_android_skyjam.MutatePlaylistEntryRequest\x12\x1f\n\x11send_notification\x18\x03 \x01(\x08:\x04true\x12\'\n\x19\x64\x65tect_timestamp_conflict\x18\x04 \x01(\x08:\x04true\x12*\n\x1bnotify_fine_grained_updates\x18\x05 \x01(\x08:\x05\x66\x61lse\"\xa1\x02\n\"BatchMutatePlaylistEntriesResponse\x12y\n\rresponse_code\x18\x01 \x03(\x0e\x32\x62.wireless_android_skyjam.BatchMutatePlaylistEntriesResponse.BatchMutatePlaylistEntriesResponseCode\x12@\n\x0fmutate_response\x18\x02 \x03(\x0b\x32\'.wireless_android_skyjam.MutateResponse\">\n&BatchMutatePlaylistEntriesResponseCode\x12\x06\n\x02OK\x10\x01\x12\x0c\n\x08\x43ONFLICT\x10\x02\"\xa8\x01\n\x11MagicPlaylistSeed\x12\x46\n\tseed_type\x18\x01 \x02(\x0e\x32\x33.wireless_android_skyjam.MagicPlaylistSeed.SeedType\x12\x0c\n\x04seed\x18\x02 \x02(\t\"=\n\x08SeedType\x12\t\n\x05TRACK\x10\x00\x12\n\n\x06\x41RTIST\x10\x01\x12\t\n\x05\x41LBUM\x10\x02\x12\x0f\n\x0bOPAQUE_SEED\x10\x03\"\xe9\x01\n\x14MagicPlaylistRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x15\n\rplaylist_name\x18\x02 \x01(\t\x12\x13\n\x0bplaylist_id\x18\x03 \x01(\t\x12\x38\n\x04seed\x18\x04 \x03(\x0b\x32*.wireless_android_skyjam.MagicPlaylistSeed\x12\x1b\n\x13num_recommendations\x18\x05 \x01(\x05\x12)\n\x1ainclude_all_track_metadata\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x12\n\nmodel_name\x18\x07 \x01(\t\"\x8c\x01\n\x15MagicPlaylistResponse\x12\x33\n\x08playlist\x18\x01 \x01(\x0b\x32!.wireless_android_skyjam.Playlist\x12>\n\x0eplaylist_entry\x18\x02 \x03(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\"\xf8\x01\n\x12\x46lushLockerRequest\x12\x0f\n\x07gaia_id\x18\x01 \x01(\x03\x12\x13\n\x0bgaia_cookie\x18\x02 \x01(\t\x12#\n\x15remove_audio_binaries\x18\x03 \x01(\x08:\x04true\x12#\n\x15remove_image_binaries\x18\x04 \x01(\x08:\x04true\x12\x1f\n\x11send_notification\x18\x05 \x01(\x08:\x04true\x12&\n\x17reset_subscription_type\x18\x06 \x01(\x08:\x05\x66\x61lse\x12)\n\x1bnotify_fine_grained_updates\x18\x08 \x01(\x08:\x04true\"\x8a\x01\n\x13\x46lushLockerResponse\x12\x16\n\x0etracks_removed\x18\x01 \x01(\x05\x12\x17\n\x0f\x65ntries_removed\x18\x02 \x01(\x05\x12\x19\n\x11playlists_removed\x18\x03 \x01(\x05\x12\'\n\x1fsuccess_reset_subscription_type\x18\x04 \x01(\x08\"6\n\x12LockerNotification\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"\xee\x01\n\x05\x41lbum\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x61lbum_artist\x18\x02 \x01(\t\x12\x34\n\talbum_art\x18\x03 \x01(\x0b\x32!.wireless_android_skyjam.ImageRef\x12\x13\n\x0btrack_count\x18\x04 \x01(\x05\x12\x18\n\x10last_time_played\x18\x05 \x01(\x03\x12\x16\n\x0eis_compilation\x18\x06 \x01(\x08\x12\x18\n\x10\x61lbum_metajam_id\x18\x07 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x08 \x01(\x03\x12\x0e\n\x06\x61rtist\x18\t \x01(\t\"\xbb\x01\n\x0e\x41lbumSortOrder\x12I\n\tattribute\x18\x01 \x01(\x0e\x32\x36.wireless_android_skyjam.AlbumSortOrder.AlbumAttribute\x12\x19\n\ndescending\x18\x02 \x01(\x08:\x05\x66\x61lse\"C\n\x0e\x41lbumAttribute\x12\x14\n\x10LAST_PLAYED_TIME\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x11\n\rCREATION_TIME\x10\x03\"u\n\x10GetAlbumsRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12;\n\nsort_order\x18\x02 \x01(\x0b\x32\'.wireless_android_skyjam.AlbumSortOrder\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\"B\n\x11GetAlbumsResponse\x12-\n\x05\x61lbum\x18\x01 \x03(\x0b\x32\x1e.wireless_android_skyjam.Album\"`\n\x06\x41rtist\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11total_track_count\x18\x02 \x01(\x05\x12-\n\x05\x61lbum\x18\x03 \x03(\x0b\x32\x1e.wireless_android_skyjam.Album\",\n\x0f\x41rtistSortOrder\x12\x19\n\ndescending\x18\x02 \x01(\x08:\x05\x66\x61lse\"w\n\x11GetArtistsRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12<\n\nsort_order\x18\x02 \x01(\x0b\x32(.wireless_android_skyjam.ArtistSortOrder\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\"E\n\x12GetArtistsResponse\x12/\n\x06\x61rtist\x18\x01 \x03(\x0b\x32\x1f.wireless_android_skyjam.Artist\"d\n\nMusicGenre\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11total_track_count\x18\x02 \x01(\x05\x12-\n\x05\x61lbum\x18\x03 \x03(\x0b\x32\x1e.wireless_android_skyjam.Album\"+\n\x0eGenreSortOrder\x12\x19\n\ndescending\x18\x02 \x01(\x08:\x05\x66\x61lse\"u\n\x10GetGenresRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12;\n\nsort_order\x18\x02 \x01(\x0b\x32\'.wireless_android_skyjam.GenreSortOrder\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\"G\n\x11GetGenresResponse\x12\x32\n\x05genre\x18\x01 \x03(\x0b\x32#.wireless_android_skyjam.MusicGenre\"\xfe\x02\n GetDynamicPlaylistEntriesRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12s\n\x15playlist_entries_type\x18\x04 \x02(\x0e\x32T.wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.DynamicPlaylistEntriesType\x12\x13\n\x0bmax_results\x18\x02 \x01(\x05\x12\x1a\n\x12\x63ontinuation_token\x18\x03 \x01(\t\x12)\n\x1ainclude_all_track_metadata\x18\x05 \x01(\x08:\x05\x66\x61lse\"x\n\x1a\x44ynamicPlaylistEntriesType\x12\r\n\tPURCHASED\x10\x01\x12\r\n\tTHUMBS_UP\x10\x02\x12\x12\n\x0eRECENTLY_ADDED\x10\x03\x12\x0c\n\x08PROMOTED\x10\x04\x12\x1a\n\x16PROMOTED_AND_PURCHASED\x10\x05\"\xa2\x04\n!GetDynamicPlaylistEntriesResponse\x12^\n\rresponse_code\x18\x01 \x02(\x0e\x32G.wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.ResponseCode\x12>\n\x0eplaylist_entry\x18\x02 \x03(\x0b\x32&.wireless_android_skyjam.PlaylistEntry\x12\x1f\n\x17\x65stimated_total_results\x18\x03 \x01(\x03\x12\x1a\n\x12\x63ontinuation_token\x18\x04 \x01(\t\x12t\n\x15playlist_entries_type\x18\x05 \x01(\x0e\x32U.wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.DynamicPlaylistEntriesType\"\x85\x01\n\x1a\x44ynamicPlaylistEntriesType\x12\r\n\tPURCHASED\x10\x01\x12\r\n\tTHUMBS_UP\x10\x02\x12\x12\n\x0eRECENTLY_ADDED\x10\x03\x12\x0c\n\x08PROMOTED\x10\x04\x12\x0b\n\x07UNKNOWN\x10\x05\x12\x1a\n\x16PROMOTED_AND_PURCHASED\x10\x06\"\"\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\n\n\x06NOT_OK\x10\x02\"4\n!GetAggregationsByTrackTypeRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\"\x82\x02\n\x12TrackTypeAggregate\x12O\n\x10track_type_value\x18\x01 \x01(\x0e\x32\x35.wireless_android_skyjam.TrackTypeAggregate.TrackType\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x8b\x01\n\tTrackType\x12\x11\n\rMATCHED_TRACK\x10\x01\x12\x13\n\x0fUNMATCHED_TRACK\x10\x02\x12\x0f\n\x0bLOCAL_TRACK\x10\x03\x12\x13\n\x0fPURCHASED_TRACK\x10\x04\x12\x1f\n\x1bMETADATA_ONLY_MATCHED_TRACK\x10\x05\x12\x0f\n\x0bPROMO_TRACK\x10\x06\"o\n\"GetAggregationsByTrackTypeResponse\x12I\n\x14track_type_aggregate\x18\x01 \x03(\x0b\x32+.wireless_android_skyjam.TrackTypeAggregate\"=\n*GetAggregationsByAvailabilityStatusRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\"\x9b\x02\n\x1b\x41vailabilityStatusAggregate\x12\x64\n\x13\x61vailability_status\x18\x01 \x01(\x0e\x32G.wireless_android_skyjam.AvailabilityStatusAggregate.AvailabilityStatus\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x86\x01\n\x12\x41vailabilityStatus\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07MATCHED\x10\x02\x12\x14\n\x10UPLOAD_REQUESTED\x10\x03\x12\r\n\tAVAILABLE\x10\x04\x12\x12\n\x0e\x46ORCE_REUPLOAD\x10\x05\x12\x1d\n\x19UPLOAD_PERMANENTLY_FAILED\x10\x06\"\x8a\x01\n+GetAggregationsByAvailabilityStatusResponse\x12[\n\x1d\x61vailability_status_aggregate\x18\x01 \x03(\x0b\x32\x34.wireless_android_skyjam.AvailabilityStatusAggregate\"7\n\x15\x41\x64\x64PromoTracksRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\r\n\x05genre\x18\x02 \x03(\t\"G\n\x16\x41\x64\x64PromoTracksResponse\x12-\n\x05track\x18\x01 \x03(\x0b\x32\x1e.wireless_android_skyjam.Track\"J\n\x1eGetPlaylistAggregationsRequest\x12\x0f\n\x07gaia_id\x18\x01 \x02(\x03\x12\x17\n\x0bmax_results\x18\x02 \x01(\x05:\x02\x31\x34\"\x9b\x01\n\x11PlaylistAggregate\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x34\n\talbum_art\x18\x03 \x01(\x0b\x32!.wireless_android_skyjam.ImageRef\x12\x13\n\x0btrack_count\x18\x04 \x01(\x03\x12\x18\n\x10last_time_played\x18\x05 \x01(\x03\"i\n\x1fGetPlaylistAggregationsResponse\x12\x46\n\x12playlist_aggregate\x18\x01 \x03(\x0b\x32*.wireless_android_skyjam.PlaylistAggregate\"?\n\x1bRemoteControlCommandRequest\x12\x0f\n\x07gaia_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"\xcb\x01\n\x1cRemoteControlCommandResponse\x12Y\n\rresponse_code\x18\x01 \x01(\x0e\x32\x42.wireless_android_skyjam.RemoteControlCommandResponse.ResponseCode\"P\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\x10\n\x0cNO_PUBLISHER\x10\x02\x12\x13\n\x0fINVALID_REQUEST\x10\x03\x12\x11\n\rPUBLISH_ERROR\x10\x04')
  ,
  dependencies=[uits__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_AUDIOREF_STORE = _descriptor.EnumDescriptor(
  name='Store',
  full_name='wireless_android_skyjam.AudioRef.Store',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BLOBSTORE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SM_V2', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=293,
  serialized_end=326,
)
_sym_db.RegisterEnumDescriptor(_AUDIOREF_STORE)

_IMAGEREF_STORE = _descriptor.EnumDescriptor(
  name='Store',
  full_name='wireless_android_skyjam.ImageRef.Store',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHOEBOX', index=0, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=531,
  serialized_end=551,
)
_sym_db.RegisterEnumDescriptor(_IMAGEREF_STORE)

_IMAGEREF_ORIGIN = _descriptor.EnumDescriptor(
  name='Origin',
  full_name='wireless_android_skyjam.ImageRef.Origin',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERSONAL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=553,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_IMAGEREF_ORIGIN)

_TRACK_AVAILABILITYSTATUS = _descriptor.EnumDescriptor(
  name='AvailabilityStatus',
  full_name='wireless_android_skyjam.Track.AvailabilityStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_REQUESTED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORCE_REUPLOAD', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_PERMANENTLY_FAILED', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2761,
  serialized_end=2895,
)
_sym_db.RegisterEnumDescriptor(_TRACK_AVAILABILITYSTATUS)

_TRACK_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='wireless_android_skyjam.Track.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MP3', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='M4A', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AAC', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLAC', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OGG', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WMA', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='M4P', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALAC', index=7, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2897,
  serialized_end=2984,
)
_sym_db.RegisterEnumDescriptor(_TRACK_CONTENTTYPE)

_TRACK_CHANNELS = _descriptor.EnumDescriptor(
  name='Channels',
  full_name='wireless_android_skyjam.Track.Channels',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MONO', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STEREO', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2986,
  serialized_end=3018,
)
_sym_db.RegisterEnumDescriptor(_TRACK_CHANNELS)

_TRACK_TRACKTYPE = _descriptor.EnumDescriptor(
  name='TrackType',
  full_name='wireless_android_skyjam.Track.TrackType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCHED_TRACK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMATCHED_TRACK', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL_TRACK', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PURCHASED_TRACK', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METADATA_ONLY_MATCHED_TRACK', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMO_TRACK', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3021,
  serialized_end=3160,
)
_sym_db.RegisterEnumDescriptor(_TRACK_TRACKTYPE)

_TRACK_RATING = _descriptor.EnumDescriptor(
  name='Rating',
  full_name='wireless_android_skyjam.Track.Rating',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_RATED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONE_STAR', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWO_STARS', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THREE_STARS', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOUR_STARS', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIVE_STARS', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3162,
  serialized_end=3263,
)
_sym_db.RegisterEnumDescriptor(_TRACK_RATING)

_TRACK_EXPLICITTYPE = _descriptor.EnumDescriptor(
  name='ExplicitType',
  full_name='wireless_android_skyjam.Track.ExplicitType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXPLICIT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEAN', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EDITED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3265,
  serialized_end=3316,
)
_sym_db.RegisterEnumDescriptor(_TRACK_EXPLICITTYPE)

_PLAYLIST_PLAYLISTTYPE = _descriptor.EnumDescriptor(
  name='PlaylistType',
  full_name='wireless_android_skyjam.Playlist.PlaylistType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER_GENERATED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAGIC', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMO', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3676,
  serialized_end=3732,
)
_sym_db.RegisterEnumDescriptor(_PLAYLIST_PLAYLISTTYPE)

_PLAYLISTENTRY_RELATIVEPOSITIONIDTYPE = _descriptor.EnumDescriptor(
  name='RelativePositionIdType',
  full_name='wireless_android_skyjam.PlaylistEntry.RelativePositionIdType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVER', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4165,
  serialized_end=4213,
)
_sym_db.RegisterEnumDescriptor(_PLAYLISTENTRY_RELATIVEPOSITIONIDTYPE)

_TRACKSEARCHRESTRICTION_TRACKATTRIBUTE = _descriptor.EnumDescriptor(
  name='TrackAttribute',
  full_name='wireless_android_skyjam.TrackSearchRestriction.TrackAttribute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TITLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARTIST', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALBUM', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALBUM_ARTIST', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENRE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABILITY_STATUS', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACK_TYPE', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEAR', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_ID', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALBUM_METAJAM_ID', index=9, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4430,
  serialized_end=4596,
)
_sym_db.RegisterEnumDescriptor(_TRACKSEARCHRESTRICTION_TRACKATTRIBUTE)

_TRACKSEARCHRESTRICTION_COMPARISONTYPE = _descriptor.EnumDescriptor(
  name='ComparisonType',
  full_name='wireless_android_skyjam.TrackSearchRestriction.ComparisonType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_EQUAL', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_EQUAL', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTIAL_MATCH', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4599,
  serialized_end=4728,
)
_sym_db.RegisterEnumDescriptor(_TRACKSEARCHRESTRICTION_COMPARISONTYPE)

_TRACKSEARCHRESTRICTIONSET_RESTRICTIONSETTYPE = _descriptor.EnumDescriptor(
  name='RestrictionSetType',
  full_name='wireless_android_skyjam.TrackSearchRestrictionSet.RestrictionSetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OR', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4984,
  serialized_end=5021,
)
_sym_db.RegisterEnumDescriptor(_TRACKSEARCHRESTRICTIONSET_RESTRICTIONSETTYPE)

_TRACKSORTORDER_TRACKATTRIBUTE = _descriptor.EnumDescriptor(
  name='TrackAttribute',
  full_name='wireless_android_skyjam.TrackSortOrder.TrackAttribute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LAST_MODIFIED_TIME', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARTIST', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALBUM', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TITLE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACK_NUMBER', index=4, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLAY_COUNT', index=5, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DURATION_MILLIS', index=6, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RATING', index=7, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATION_TIME', index=8, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5144,
  serialized_end=5304,
)
_sym_db.RegisterEnumDescriptor(_TRACKSORTORDER_TRACKATTRIBUTE)

_GETTRACKSREQUEST_TRACKPROJECTION = _descriptor.EnumDescriptor(
  name='TrackProjection',
  full_name='wireless_android_skyjam.GetTracksRequest.TrackProjection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FULL', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FRONTEND_VIEW', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5739,
  serialized_end=5785,
)
_sym_db.RegisterEnumDescriptor(_GETTRACKSREQUEST_TRACKPROJECTION)

_GETTRACKSRESPONSE_RESPONSECODE = _descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='wireless_android_skyjam.GetTracksResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_MODIFIED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GONE', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5997,
  serialized_end=6047,
)
_sym_db.RegisterEnumDescriptor(_GETTRACKSRESPONSE_RESPONSECODE)

_GETPLAYLISTENTRIESRESPONSE_RESPONSECODE = _descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='wireless_android_skyjam.GetPlaylistEntriesResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_MODIFIED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GONE', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5997,
  serialized_end=6047,
)
_sym_db.RegisterEnumDescriptor(_GETPLAYLISTENTRIESRESPONSE_RESPONSECODE)

_PLAYLISTSORTORDER_PLAYLISTATTRIBUTE = _descriptor.EnumDescriptor(
  name='PlaylistAttribute',
  full_name='wireless_android_skyjam.PlaylistSortOrder.PlaylistAttribute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LAST_MODIFIED_TIME', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TITLE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATION_TIME', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECENT_TIMESTAMP', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6731,
  serialized_end=6826,
)
_sym_db.RegisterEnumDescriptor(_PLAYLISTSORTORDER_PLAYLISTATTRIBUTE)

_GETPLAYLISTSRESPONSE_RESPONSECODE = _descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='wireless_android_skyjam.GetPlaylistsResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_MODIFIED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GONE', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=5997,
  serialized_end=6047,
)
_sym_db.RegisterEnumDescriptor(_GETPLAYLISTSRESPONSE_RESPONSECODE)

_BATCHLOOKUPREQUEST_METADATATYPE = _descriptor.EnumDescriptor(
  name='MetadataType',
  full_name='wireless_android_skyjam.BatchLookupRequest.MetadataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLAYLIST', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLAYLIST_ENTRY', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7828,
  serialized_end=7887,
)
_sym_db.RegisterEnumDescriptor(_BATCHLOOKUPREQUEST_METADATATYPE)

_MUTATERESPONSE_MUTATERESPONSECODE = _descriptor.EnumDescriptor(
  name='MutateResponseCode',
  full_name='wireless_android_skyjam.MutateResponse.MutateResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFLICT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REQUEST', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METADATA_TOO_LARGE', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8577,
  serialized_end=8664,
)
_sym_db.RegisterEnumDescriptor(_MUTATERESPONSE_MUTATERESPONSECODE)

_MUTATERESPONSE_AVAILABILITYSTATUS = _descriptor.EnumDescriptor(
  name='AvailabilityStatus',
  full_name='wireless_android_skyjam.MutateResponse.AvailabilityStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_REQUESTED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORCE_REUPLOAD', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_PERMANENTLY_FAILED', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2761,
  serialized_end=2895,
)
_sym_db.RegisterEnumDescriptor(_MUTATERESPONSE_AVAILABILITYSTATUS)

_BATCHMUTATETRACKSRESPONSE_BATCHMUTATETRACKSRESPONSECODE = _descriptor.EnumDescriptor(
  name='BatchMutateTracksResponseCode',
  full_name='wireless_android_skyjam.BatchMutateTracksResponse.BatchMutateTracksResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFLICT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9236,
  serialized_end=9289,
)
_sym_db.RegisterEnumDescriptor(_BATCHMUTATETRACKSRESPONSE_BATCHMUTATETRACKSRESPONSECODE)

_BATCHMUTATEPLAYLISTSRESPONSE_BATCHMUTATEPLAYLISTSRESPONSECODE = _descriptor.EnumDescriptor(
  name='BatchMutatePlaylistsResponseCode',
  full_name='wireless_android_skyjam.BatchMutatePlaylistsResponse.BatchMutatePlaylistsResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFLICT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10065,
  serialized_end=10121,
)
_sym_db.RegisterEnumDescriptor(_BATCHMUTATEPLAYLISTSRESPONSE_BATCHMUTATEPLAYLISTSRESPONSECODE)

_BATCHMUTATEPLAYLISTENTRIESRESPONSE_BATCHMUTATEPLAYLISTENTRIESRESPONSECODE = _descriptor.EnumDescriptor(
  name='BatchMutatePlaylistEntriesResponseCode',
  full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesResponse.BatchMutatePlaylistEntriesResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFLICT', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10923,
  serialized_end=10985,
)
_sym_db.RegisterEnumDescriptor(_BATCHMUTATEPLAYLISTENTRIESRESPONSE_BATCHMUTATEPLAYLISTENTRIESRESPONSECODE)

_MAGICPLAYLISTSEED_SEEDTYPE = _descriptor.EnumDescriptor(
  name='SeedType',
  full_name='wireless_android_skyjam.MagicPlaylistSeed.SeedType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRACK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARTIST', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALBUM', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPAQUE_SEED', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=11095,
  serialized_end=11156,
)
_sym_db.RegisterEnumDescriptor(_MAGICPLAYLISTSEED_SEEDTYPE)

_ALBUMSORTORDER_ALBUMATTRIBUTE = _descriptor.EnumDescriptor(
  name='AlbumAttribute',
  full_name='wireless_android_skyjam.AlbumSortOrder.AlbumAttribute',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LAST_PLAYED_TIME', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATION_TIME', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=12347,
  serialized_end=12414,
)
_sym_db.RegisterEnumDescriptor(_ALBUMSORTORDER_ALBUMATTRIBUTE)

_GETDYNAMICPLAYLISTENTRIESREQUEST_DYNAMICPLAYLISTENTRIESTYPE = _descriptor.EnumDescriptor(
  name='DynamicPlaylistEntriesType',
  full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.DynamicPlaylistEntriesType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PURCHASED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUMBS_UP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECENTLY_ADDED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTED', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTED_AND_PURCHASED', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=13541,
  serialized_end=13661,
)
_sym_db.RegisterEnumDescriptor(_GETDYNAMICPLAYLISTENTRIESREQUEST_DYNAMICPLAYLISTENTRIESTYPE)

_GETDYNAMICPLAYLISTENTRIESRESPONSE_DYNAMICPLAYLISTENTRIESTYPE = _descriptor.EnumDescriptor(
  name='DynamicPlaylistEntriesType',
  full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.DynamicPlaylistEntriesType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PURCHASED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUMBS_UP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECENTLY_ADDED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTED', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTED_AND_PURCHASED', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=14041,
  serialized_end=14174,
)
_sym_db.RegisterEnumDescriptor(_GETDYNAMICPLAYLISTENTRIESRESPONSE_DYNAMICPLAYLISTENTRIESTYPE)

_GETDYNAMICPLAYLISTENTRIESRESPONSE_RESPONSECODE = _descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_OK', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=14176,
  serialized_end=14210,
)
_sym_db.RegisterEnumDescriptor(_GETDYNAMICPLAYLISTENTRIESRESPONSE_RESPONSECODE)

_TRACKTYPEAGGREGATE_TRACKTYPE = _descriptor.EnumDescriptor(
  name='TrackType',
  full_name='wireless_android_skyjam.TrackTypeAggregate.TrackType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MATCHED_TRACK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNMATCHED_TRACK', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL_TRACK', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PURCHASED_TRACK', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METADATA_ONLY_MATCHED_TRACK', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMO_TRACK', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3021,
  serialized_end=3160,
)
_sym_db.RegisterEnumDescriptor(_TRACKTYPEAGGREGATE_TRACKTYPE)

_AVAILABILITYSTATUSAGGREGATE_AVAILABILITYSTATUS = _descriptor.EnumDescriptor(
  name='AvailabilityStatus',
  full_name='wireless_android_skyjam.AvailabilityStatusAggregate.AvailabilityStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATCHED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_REQUESTED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORCE_REUPLOAD', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_PERMANENTLY_FAILED', index=5, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2761,
  serialized_end=2895,
)
_sym_db.RegisterEnumDescriptor(_AVAILABILITYSTATUSAGGREGATE_AVAILABILITYSTATUS)

_REMOTECONTROLCOMMANDRESPONSE_RESPONSECODE = _descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='wireless_android_skyjam.RemoteControlCommandResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_PUBLISHER', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REQUEST', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLISH_ERROR', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=15790,
  serialized_end=15870,
)
_sym_db.RegisterEnumDescriptor(_REMOTECONTROLCOMMANDRESPONSE_RESPONSECODE)


_AUDIOREF = _descriptor.Descriptor(
  name='AudioRef',
  full_name='wireless_android_skyjam.AudioRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store', full_name='wireless_android_skyjam.AudioRef.store', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ref', full_name='wireless_android_skyjam.AudioRef.ref', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='wireless_android_skyjam.AudioRef.url', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bit_rate', full_name='wireless_android_skyjam.AudioRef.bit_rate', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='wireless_android_skyjam.AudioRef.sample_rate', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='downloadable', full_name='wireless_android_skyjam.AudioRef.downloadable', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_millis', full_name='wireless_android_skyjam.AudioRef.duration_millis', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rematch_timestamp', full_name='wireless_android_skyjam.AudioRef.rematch_timestamp', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invalid_due_to_wipeout', full_name='wireless_android_skyjam.AudioRef.invalid_due_to_wipeout', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUDIOREF_STORE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=326,
)


_IMAGEREF = _descriptor.Descriptor(
  name='ImageRef',
  full_name='wireless_android_skyjam.ImageRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store', full_name='wireless_android_skyjam.ImageRef.store', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='wireless_android_skyjam.ImageRef.width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='wireless_android_skyjam.ImageRef.height', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='wireless_android_skyjam.ImageRef.url', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invalid_due_to_wipeout', full_name='wireless_android_skyjam.ImageRef.invalid_due_to_wipeout', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='wireless_android_skyjam.ImageRef.origin', index=5,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGEREF_STORE,
    _IMAGEREF_ORIGIN,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=586,
)


_UPLOADEDUITSID3TAG = _descriptor.Descriptor(
  name='UploadedUitsId3Tag',
  full_name='wireless_android_skyjam.UploadedUitsId3Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner', full_name='wireless_android_skyjam.UploadedUitsId3Tag.owner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='wireless_android_skyjam.UploadedUitsId3Tag.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=637,
)


_ADDITIONALMETADATA = _descriptor.Descriptor(
  name='AdditionalMetadata',
  full_name='wireless_android_skyjam.AdditionalMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='wireless_android_skyjam.AdditionalMetadata.tag_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='wireless_android_skyjam.AdditionalMetadata.value', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=692,
)


_TRACKEXTRAS = _descriptor.Descriptor(
  name='TrackExtras',
  full_name='wireless_android_skyjam.TrackExtras',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_metadata', full_name='wireless_android_skyjam.TrackExtras.additional_metadata', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='candidates', full_name='wireless_android_skyjam.TrackExtras.candidates', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_sample_rate', full_name='wireless_android_skyjam.TrackExtras.original_sample_rate', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=832,
)


_TRACK = _descriptor.Descriptor(
  name='Track',
  full_name='wireless_android_skyjam.Track',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.Track.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.Track.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='wireless_android_skyjam.Track.creation_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified_timestamp', full_name='wireless_android_skyjam.Track.last_modified_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='wireless_android_skyjam.Track.deleted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='wireless_android_skyjam.Track.title', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='artist', full_name='wireless_android_skyjam.Track.artist', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='artist_hash', full_name='wireless_android_skyjam.Track.artist_hash', index=7,
      number=46, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='composer', full_name='wireless_android_skyjam.Track.composer', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album', full_name='wireless_android_skyjam.Track.album', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_artist', full_name='wireless_android_skyjam.Track.album_artist', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='canonical_album', full_name='wireless_android_skyjam.Track.canonical_album', index=11,
      number=56, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='canonical_artist', full_name='wireless_android_skyjam.Track.canonical_artist', index=12,
      number=57, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='canonical_genre_album', full_name='wireless_android_skyjam.Track.canonical_genre_album', index=13,
      number=58, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='year', full_name='wireless_android_skyjam.Track.year', index=14,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comment', full_name='wireless_android_skyjam.Track.comment', index=15,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_number', full_name='wireless_android_skyjam.Track.track_number', index=16,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='genre', full_name='wireless_android_skyjam.Track.genre', index=17,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_millis', full_name='wireless_android_skyjam.Track.duration_millis', index=18,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='beats_per_minute', full_name='wireless_android_skyjam.Track.beats_per_minute', index=19,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_bit_rate', full_name='wireless_android_skyjam.Track.original_bit_rate', index=20,
      number=44, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio_ref', full_name='wireless_android_skyjam.Track.audio_ref', index=21,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_art_ref', full_name='wireless_android_skyjam.Track.album_art_ref', index=22,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='availability_status', full_name='wireless_android_skyjam.Track.availability_status', index=23,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='play_count', full_name='wireless_android_skyjam.Track.play_count', index=24,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='wireless_android_skyjam.Track.content_type', index=25,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_track_count', full_name='wireless_android_skyjam.Track.total_track_count', index=26,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='disc_number', full_name='wireless_android_skyjam.Track.disc_number', index=27,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_disc_count', full_name='wireless_android_skyjam.Track.total_disc_count', index=28,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='channels', full_name='wireless_android_skyjam.Track.channels', index=29,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_type', full_name='wireless_android_skyjam.Track.track_type', index=30,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_single_server_copy', full_name='wireless_android_skyjam.Track.use_single_server_copy', index=31,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rating', full_name='wireless_android_skyjam.Track.rating', index=32,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_size', full_name='wireless_android_skyjam.Track.estimated_size', index=33,
      number=32, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='store_id', full_name='wireless_android_skyjam.Track.store_id', index=34,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metajam_id', full_name='wireless_android_skyjam.Track.metajam_id', index=35,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metajam_id_confidence', full_name='wireless_android_skyjam.Track.metajam_id_confidence', index=36,
      number=43, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uits', full_name='wireless_android_skyjam.Track.uits', index=37,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uits_metadata', full_name='wireless_android_skyjam.Track.uits_metadata', index=38,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='compilation', full_name='wireless_android_skyjam.Track.compilation', index=39,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_date_added', full_name='wireless_android_skyjam.Track.client_date_added', index=40,
      number=37, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_timestamp', full_name='wireless_android_skyjam.Track.recent_timestamp', index=41,
      number=38, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_not_rematch', full_name='wireless_android_skyjam.Track.do_not_rematch', index=42,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_album_purchase', full_name='wireless_android_skyjam.Track.from_album_purchase', index=43,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_metajam_id', full_name='wireless_android_skyjam.Track.album_metajam_id', index=44,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='wireless_android_skyjam.Track.transaction_id', index=45,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_track', full_name='wireless_android_skyjam.Track.debug_track', index=46,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_title', full_name='wireless_android_skyjam.Track.normalized_title', index=47,
      number=48, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_artist', full_name='wireless_android_skyjam.Track.normalized_artist', index=48,
      number=49, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_album', full_name='wireless_android_skyjam.Track.normalized_album', index=49,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_album_artist', full_name='wireless_android_skyjam.Track.normalized_album_artist', index=50,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_canonical_album', full_name='wireless_android_skyjam.Track.normalized_canonical_album', index=51,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalized_canonical_artist', full_name='wireless_android_skyjam.Track.normalized_canonical_artist', index=52,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uploader_id', full_name='wireless_android_skyjam.Track.uploader_id', index=53,
      number=52, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_album_id', full_name='wireless_android_skyjam.Track.client_album_id', index=54,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label_owner_code', full_name='wireless_android_skyjam.Track.label_owner_code', index=55,
      number=60, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_content_type', full_name='wireless_android_skyjam.Track.original_content_type', index=56,
      number=61, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uploaded_uits', full_name='wireless_android_skyjam.Track.uploaded_uits', index=57,
      number=71, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='explicit_type', full_name='wireless_android_skyjam.Track.explicit_type', index=58,
      number=74, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_extras', full_name='wireless_android_skyjam.Track.track_extras', index=59,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACK_AVAILABILITYSTATUS,
    _TRACK_CONTENTTYPE,
    _TRACK_CHANNELS,
    _TRACK_TRACKTYPE,
    _TRACK_RATING,
    _TRACK_EXPLICITTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=3316,
)


_TRACKS = _descriptor.Descriptor(
  name='Tracks',
  full_name='wireless_android_skyjam.Tracks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.Tracks.track', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3318,
  serialized_end=3373,
)


_PLAYLIST = _descriptor.Descriptor(
  name='Playlist',
  full_name='wireless_android_skyjam.Playlist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.Playlist.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.Playlist.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='wireless_android_skyjam.Playlist.creation_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified_timestamp', full_name='wireless_android_skyjam.Playlist.last_modified_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='wireless_android_skyjam.Playlist.deleted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='wireless_android_skyjam.Playlist.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_type', full_name='wireless_android_skyjam.Playlist.playlist_type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_art_ref', full_name='wireless_android_skyjam.Playlist.playlist_art_ref', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_timestamp', full_name='wireless_android_skyjam.Playlist.recent_timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAYLIST_PLAYLISTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3376,
  serialized_end=3732,
)


_PLAYLISTENTRY = _descriptor.Descriptor(
  name='PlaylistEntry',
  full_name='wireless_android_skyjam.PlaylistEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='playlist_id', full_name='wireless_android_skyjam.PlaylistEntry.playlist_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='absolute_position', full_name='wireless_android_skyjam.PlaylistEntry.absolute_position', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='place_after_entry_id', full_name='wireless_android_skyjam.PlaylistEntry.place_after_entry_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_id', full_name='wireless_android_skyjam.PlaylistEntry.track_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.PlaylistEntry.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.PlaylistEntry.client_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='wireless_android_skyjam.PlaylistEntry.creation_timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_modified_timestamp', full_name='wireless_android_skyjam.PlaylistEntry.last_modified_timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='wireless_android_skyjam.PlaylistEntry.deleted', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relative_position_id_type', full_name='wireless_android_skyjam.PlaylistEntry.relative_position_id_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.PlaylistEntry.track', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='place_before_entry_id', full_name='wireless_android_skyjam.PlaylistEntry.place_before_entry_id', index=11,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_position', full_name='wireless_android_skyjam.PlaylistEntry.string_position', index=12,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAYLISTENTRY_RELATIVEPOSITIONIDTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3735,
  serialized_end=4213,
)


_TRACKSEARCHRESTRICTION = _descriptor.Descriptor(
  name='TrackSearchRestriction',
  full_name='wireless_android_skyjam.TrackSearchRestriction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='wireless_android_skyjam.TrackSearchRestriction.attribute', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='wireless_android_skyjam.TrackSearchRestriction.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comparison_type', full_name='wireless_android_skyjam.TrackSearchRestriction.comparison_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKSEARCHRESTRICTION_TRACKATTRIBUTE,
    _TRACKSEARCHRESTRICTION_COMPARISONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4216,
  serialized_end=4728,
)


_TRACKSEARCHRESTRICTIONSET = _descriptor.Descriptor(
  name='TrackSearchRestrictionSet',
  full_name='wireless_android_skyjam.TrackSearchRestrictionSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='wireless_android_skyjam.TrackSearchRestrictionSet.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='restriction', full_name='wireless_android_skyjam.TrackSearchRestrictionSet.restriction', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sub_set', full_name='wireless_android_skyjam.TrackSearchRestrictionSet.sub_set', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKSEARCHRESTRICTIONSET_RESTRICTIONSETTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4731,
  serialized_end=5021,
)


_TRACKSORTORDER = _descriptor.Descriptor(
  name='TrackSortOrder',
  full_name='wireless_android_skyjam.TrackSortOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='wireless_android_skyjam.TrackSortOrder.attribute', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='descending', full_name='wireless_android_skyjam.TrackSortOrder.descending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKSORTORDER_TRACKATTRIBUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5024,
  serialized_end=5304,
)


_GETTRACKSREQUEST = _descriptor.Descriptor(
  name='GetTracksRequest',
  full_name='wireless_android_skyjam.GetTracksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetTracksRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_min', full_name='wireless_android_skyjam.GetTracksRequest.updated_min', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_deleted', full_name='wireless_android_skyjam.GetTracksRequest.include_deleted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetTracksRequest.max_results', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetTracksRequest.continuation_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_restriction', full_name='wireless_android_skyjam.GetTracksRequest.search_restriction', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='wireless_android_skyjam.GetTracksRequest.sort_order', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='restriction_set', full_name='wireless_android_skyjam.GetTracksRequest.restriction_set', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_projection', full_name='wireless_android_skyjam.GetTracksRequest.track_projection', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETTRACKSREQUEST_TRACKPROJECTION,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5307,
  serialized_end=5785,
)


_GETTRACKSRESPONSE = _descriptor.Descriptor(
  name='GetTracksResponse',
  full_name='wireless_android_skyjam.GetTracksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.GetTracksResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.GetTracksResponse.track', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_total_results', full_name='wireless_android_skyjam.GetTracksResponse.estimated_total_results', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetTracksResponse.continuation_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETTRACKSRESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=6047,
)


_GETPLAYLISTENTRIESREQUEST = _descriptor.Descriptor(
  name='GetPlaylistEntriesRequest',
  full_name='wireless_android_skyjam.GetPlaylistEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_min', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.updated_min', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_deleted', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.include_deleted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.max_results', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.continuation_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_id_filter', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.playlist_id_filter', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_all_track_metadata', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.include_all_track_metadata', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='only_show_available_tracks', full_name='wireless_android_skyjam.GetPlaylistEntriesRequest.only_show_available_tracks', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6050,
  serialized_end=6302,
)


_GETPLAYLISTENTRIESRESPONSE = _descriptor.Descriptor(
  name='GetPlaylistEntriesResponse',
  full_name='wireless_android_skyjam.GetPlaylistEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.GetPlaylistEntriesResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.GetPlaylistEntriesResponse.playlist_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_total_results', full_name='wireless_android_skyjam.GetPlaylistEntriesResponse.estimated_total_results', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetPlaylistEntriesResponse.continuation_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETPLAYLISTENTRIESRESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6305,
  serialized_end=6599,
)


_PLAYLISTSORTORDER = _descriptor.Descriptor(
  name='PlaylistSortOrder',
  full_name='wireless_android_skyjam.PlaylistSortOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='wireless_android_skyjam.PlaylistSortOrder.attribute', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='descending', full_name='wireless_android_skyjam.PlaylistSortOrder.descending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAYLISTSORTORDER_PLAYLISTATTRIBUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6602,
  serialized_end=6826,
)


_GETPLAYLISTSREQUEST = _descriptor.Descriptor(
  name='GetPlaylistsRequest',
  full_name='wireless_android_skyjam.GetPlaylistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetPlaylistsRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_min', full_name='wireless_android_skyjam.GetPlaylistsRequest.updated_min', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_deleted', full_name='wireless_android_skyjam.GetPlaylistsRequest.include_deleted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetPlaylistsRequest.max_results', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetPlaylistsRequest.continuation_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='wireless_android_skyjam.GetPlaylistsRequest.sort_order', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6829,
  serialized_end=7026,
)


_GETPLAYLISTSRESPONSE = _descriptor.Descriptor(
  name='GetPlaylistsResponse',
  full_name='wireless_android_skyjam.GetPlaylistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.GetPlaylistsResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist', full_name='wireless_android_skyjam.GetPlaylistsResponse.playlist', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_total_results', full_name='wireless_android_skyjam.GetPlaylistsResponse.estimated_total_results', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetPlaylistsResponse.continuation_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETPLAYLISTSRESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7029,
  serialized_end=7300,
)


_LOOKUPTRACKREQUEST = _descriptor.Descriptor(
  name='LookupTrackRequest',
  full_name='wireless_android_skyjam.LookupTrackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.LookupTrackRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.LookupTrackRequest.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7302,
  serialized_end=7353,
)


_LOOKUPPLAYLISTENTRYREQUEST = _descriptor.Descriptor(
  name='LookupPlaylistEntryRequest',
  full_name='wireless_android_skyjam.LookupPlaylistEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.LookupPlaylistEntryRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.LookupPlaylistEntryRequest.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7355,
  serialized_end=7414,
)


_LOOKUPPLAYLISTREQUEST = _descriptor.Descriptor(
  name='LookupPlaylistRequest',
  full_name='wireless_android_skyjam.LookupPlaylistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.LookupPlaylistRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.LookupPlaylistRequest.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7416,
  serialized_end=7470,
)


_BATCHLOOKUPREQUEST = _descriptor.Descriptor(
  name='BatchLookupRequest',
  full_name='wireless_android_skyjam.BatchLookupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.BatchLookupRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.BatchLookupRequest.track', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist', full_name='wireless_android_skyjam.BatchLookupRequest.playlist', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata_type', full_name='wireless_android_skyjam.BatchLookupRequest.metadata_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.BatchLookupRequest.playlist_entry', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_deleted', full_name='wireless_android_skyjam.BatchLookupRequest.include_deleted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BATCHLOOKUPREQUEST_METADATATYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7473,
  serialized_end=7887,
)


_BATCHLOOKUPRESPONSE = _descriptor.Descriptor(
  name='BatchLookupResponse',
  full_name='wireless_android_skyjam.BatchLookupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.BatchLookupResponse.track', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist', full_name='wireless_android_skyjam.BatchLookupResponse.playlist', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.BatchLookupResponse.playlist_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7890,
  serialized_end=8075,
)


_MUTATETRACKREQUEST = _descriptor.Descriptor(
  name='MutateTrackRequest',
  full_name='wireless_android_skyjam.MutateTrackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_track', full_name='wireless_android_skyjam.MutateTrackRequest.create_track', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_track', full_name='wireless_android_skyjam.MutateTrackRequest.update_track', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_track', full_name='wireless_android_skyjam.MutateTrackRequest.delete_track', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partial_update', full_name='wireless_android_skyjam.MutateTrackRequest.partial_update', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_last_modified', full_name='wireless_android_skyjam.MutateTrackRequest.update_last_modified', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='undelete_track', full_name='wireless_android_skyjam.MutateTrackRequest.undelete_track', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8078,
  serialized_end=8312,
)


_MUTATERESPONSE = _descriptor.Descriptor(
  name='MutateResponse',
  full_name='wireless_android_skyjam.MutateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.MutateResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='wireless_android_skyjam.MutateResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='child_id', full_name='wireless_android_skyjam.MutateResponse.child_id', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='wireless_android_skyjam.MutateResponse.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='availability_status', full_name='wireless_android_skyjam.MutateResponse.availability_status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='wireless_android_skyjam.MutateResponse.error_message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MUTATERESPONSE_MUTATERESPONSECODE,
    _MUTATERESPONSE_AVAILABILITYSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8315,
  serialized_end=8801,
)


_BATCHMUTATETRACKSREQUEST = _descriptor.Descriptor(
  name='BatchMutateTracksRequest',
  full_name='wireless_android_skyjam.BatchMutateTracksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.BatchMutateTracksRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_mutation', full_name='wireless_android_skyjam.BatchMutateTracksRequest.track_mutation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_notification', full_name='wireless_android_skyjam.BatchMutateTracksRequest.send_notification', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detect_timestamp_conflict', full_name='wireless_android_skyjam.BatchMutateTracksRequest.detect_timestamp_conflict', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notify_fine_grained_updates', full_name='wireless_android_skyjam.BatchMutateTracksRequest.notify_fine_grained_updates', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8804,
  serialized_end=9033,
)


_BATCHMUTATETRACKSRESPONSE = _descriptor.Descriptor(
  name='BatchMutateTracksResponse',
  full_name='wireless_android_skyjam.BatchMutateTracksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.BatchMutateTracksResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mutate_response', full_name='wireless_android_skyjam.BatchMutateTracksResponse.mutate_response', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BATCHMUTATETRACKSRESPONSE_BATCHMUTATETRACKSRESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9036,
  serialized_end=9289,
)


_MUTATEPLAYLISTREQUEST = _descriptor.Descriptor(
  name='MutatePlaylistRequest',
  full_name='wireless_android_skyjam.MutatePlaylistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_playlist', full_name='wireless_android_skyjam.MutatePlaylistRequest.create_playlist', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_playlist', full_name='wireless_android_skyjam.MutatePlaylistRequest.update_playlist', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_playlist', full_name='wireless_android_skyjam.MutatePlaylistRequest.delete_playlist', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partial_update', full_name='wireless_android_skyjam.MutatePlaylistRequest.partial_update', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.MutatePlaylistRequest.playlist_entry', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_last_modified', full_name='wireless_android_skyjam.MutatePlaylistRequest.update_last_modified', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='undelete_playlist', full_name='wireless_android_skyjam.MutatePlaylistRequest.undelete_playlist', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9292,
  serialized_end=9611,
)


_BATCHMUTATEPLAYLISTSREQUEST = _descriptor.Descriptor(
  name='BatchMutatePlaylistsRequest',
  full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_mutation', full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest.playlist_mutation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_notification', full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest.send_notification', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detect_timestamp_conflict', full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest.detect_timestamp_conflict', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notify_fine_grained_updates', full_name='wireless_android_skyjam.BatchMutatePlaylistsRequest.notify_fine_grained_updates', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9614,
  serialized_end=9853,
)


_BATCHMUTATEPLAYLISTSRESPONSE = _descriptor.Descriptor(
  name='BatchMutatePlaylistsResponse',
  full_name='wireless_android_skyjam.BatchMutatePlaylistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.BatchMutatePlaylistsResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mutate_response', full_name='wireless_android_skyjam.BatchMutatePlaylistsResponse.mutate_response', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BATCHMUTATEPLAYLISTSRESPONSE_BATCHMUTATEPLAYLISTSRESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9856,
  serialized_end=10121,
)


_MUTATEPLAYLISTENTRYREQUEST = _descriptor.Descriptor(
  name='MutatePlaylistEntryRequest',
  full_name='wireless_android_skyjam.MutatePlaylistEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_playlist_entry', full_name='wireless_android_skyjam.MutatePlaylistEntryRequest.create_playlist_entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_playlist_entry', full_name='wireless_android_skyjam.MutatePlaylistEntryRequest.update_playlist_entry', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delete_playlist_entry', full_name='wireless_android_skyjam.MutatePlaylistEntryRequest.delete_playlist_entry', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update_last_modified', full_name='wireless_android_skyjam.MutatePlaylistEntryRequest.update_last_modified', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='undelete_playlist_entry', full_name='wireless_android_skyjam.MutatePlaylistEntryRequest.undelete_playlist_entry', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10124,
  serialized_end=10434,
)


_BATCHMUTATEPLAYLISTENTRIESREQUEST = _descriptor.Descriptor(
  name='BatchMutatePlaylistEntriesRequest',
  full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry_mutation', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest.playlist_entry_mutation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_notification', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest.send_notification', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detect_timestamp_conflict', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest.detect_timestamp_conflict', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notify_fine_grained_updates', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesRequest.notify_fine_grained_updates', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10437,
  serialized_end=10693,
)


_BATCHMUTATEPLAYLISTENTRIESRESPONSE = _descriptor.Descriptor(
  name='BatchMutatePlaylistEntriesResponse',
  full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mutate_response', full_name='wireless_android_skyjam.BatchMutatePlaylistEntriesResponse.mutate_response', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BATCHMUTATEPLAYLISTENTRIESRESPONSE_BATCHMUTATEPLAYLISTENTRIESRESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10696,
  serialized_end=10985,
)


_MAGICPLAYLISTSEED = _descriptor.Descriptor(
  name='MagicPlaylistSeed',
  full_name='wireless_android_skyjam.MagicPlaylistSeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seed_type', full_name='wireless_android_skyjam.MagicPlaylistSeed.seed_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seed', full_name='wireless_android_skyjam.MagicPlaylistSeed.seed', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MAGICPLAYLISTSEED_SEEDTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10988,
  serialized_end=11156,
)


_MAGICPLAYLISTREQUEST = _descriptor.Descriptor(
  name='MagicPlaylistRequest',
  full_name='wireless_android_skyjam.MagicPlaylistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.MagicPlaylistRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_name', full_name='wireless_android_skyjam.MagicPlaylistRequest.playlist_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_id', full_name='wireless_android_skyjam.MagicPlaylistRequest.playlist_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seed', full_name='wireless_android_skyjam.MagicPlaylistRequest.seed', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_recommendations', full_name='wireless_android_skyjam.MagicPlaylistRequest.num_recommendations', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_all_track_metadata', full_name='wireless_android_skyjam.MagicPlaylistRequest.include_all_track_metadata', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='wireless_android_skyjam.MagicPlaylistRequest.model_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11159,
  serialized_end=11392,
)


_MAGICPLAYLISTRESPONSE = _descriptor.Descriptor(
  name='MagicPlaylistResponse',
  full_name='wireless_android_skyjam.MagicPlaylistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='playlist', full_name='wireless_android_skyjam.MagicPlaylistResponse.playlist', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.MagicPlaylistResponse.playlist_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11395,
  serialized_end=11535,
)


_FLUSHLOCKERREQUEST = _descriptor.Descriptor(
  name='FlushLockerRequest',
  full_name='wireless_android_skyjam.FlushLockerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.FlushLockerRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gaia_cookie', full_name='wireless_android_skyjam.FlushLockerRequest.gaia_cookie', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remove_audio_binaries', full_name='wireless_android_skyjam.FlushLockerRequest.remove_audio_binaries', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remove_image_binaries', full_name='wireless_android_skyjam.FlushLockerRequest.remove_image_binaries', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='send_notification', full_name='wireless_android_skyjam.FlushLockerRequest.send_notification', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reset_subscription_type', full_name='wireless_android_skyjam.FlushLockerRequest.reset_subscription_type', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notify_fine_grained_updates', full_name='wireless_android_skyjam.FlushLockerRequest.notify_fine_grained_updates', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11538,
  serialized_end=11786,
)


_FLUSHLOCKERRESPONSE = _descriptor.Descriptor(
  name='FlushLockerResponse',
  full_name='wireless_android_skyjam.FlushLockerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracks_removed', full_name='wireless_android_skyjam.FlushLockerResponse.tracks_removed', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entries_removed', full_name='wireless_android_skyjam.FlushLockerResponse.entries_removed', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlists_removed', full_name='wireless_android_skyjam.FlushLockerResponse.playlists_removed', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='success_reset_subscription_type', full_name='wireless_android_skyjam.FlushLockerResponse.success_reset_subscription_type', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11789,
  serialized_end=11927,
)


_LOCKERNOTIFICATION = _descriptor.Descriptor(
  name='LockerNotification',
  full_name='wireless_android_skyjam.LockerNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.LockerNotification.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='payload', full_name='wireless_android_skyjam.LockerNotification.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11929,
  serialized_end=11983,
)


_ALBUM = _descriptor.Descriptor(
  name='Album',
  full_name='wireless_android_skyjam.Album',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='wireless_android_skyjam.Album.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_artist', full_name='wireless_android_skyjam.Album.album_artist', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_art', full_name='wireless_android_skyjam.Album.album_art', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_count', full_name='wireless_android_skyjam.Album.track_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_time_played', full_name='wireless_android_skyjam.Album.last_time_played', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_compilation', full_name='wireless_android_skyjam.Album.is_compilation', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_metajam_id', full_name='wireless_android_skyjam.Album.album_metajam_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='wireless_android_skyjam.Album.creation_timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='artist', full_name='wireless_android_skyjam.Album.artist', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11986,
  serialized_end=12224,
)


_ALBUMSORTORDER = _descriptor.Descriptor(
  name='AlbumSortOrder',
  full_name='wireless_android_skyjam.AlbumSortOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='wireless_android_skyjam.AlbumSortOrder.attribute', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='descending', full_name='wireless_android_skyjam.AlbumSortOrder.descending', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALBUMSORTORDER_ALBUMATTRIBUTE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12227,
  serialized_end=12414,
)


_GETALBUMSREQUEST = _descriptor.Descriptor(
  name='GetAlbumsRequest',
  full_name='wireless_android_skyjam.GetAlbumsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetAlbumsRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='wireless_android_skyjam.GetAlbumsRequest.sort_order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetAlbumsRequest.max_results', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12416,
  serialized_end=12533,
)


_GETALBUMSRESPONSE = _descriptor.Descriptor(
  name='GetAlbumsResponse',
  full_name='wireless_android_skyjam.GetAlbumsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='album', full_name='wireless_android_skyjam.GetAlbumsResponse.album', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12535,
  serialized_end=12601,
)


_ARTIST = _descriptor.Descriptor(
  name='Artist',
  full_name='wireless_android_skyjam.Artist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='wireless_android_skyjam.Artist.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_track_count', full_name='wireless_android_skyjam.Artist.total_track_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album', full_name='wireless_android_skyjam.Artist.album', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12603,
  serialized_end=12699,
)


_ARTISTSORTORDER = _descriptor.Descriptor(
  name='ArtistSortOrder',
  full_name='wireless_android_skyjam.ArtistSortOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='descending', full_name='wireless_android_skyjam.ArtistSortOrder.descending', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12701,
  serialized_end=12745,
)


_GETARTISTSREQUEST = _descriptor.Descriptor(
  name='GetArtistsRequest',
  full_name='wireless_android_skyjam.GetArtistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetArtistsRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='wireless_android_skyjam.GetArtistsRequest.sort_order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetArtistsRequest.max_results', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12747,
  serialized_end=12866,
)


_GETARTISTSRESPONSE = _descriptor.Descriptor(
  name='GetArtistsResponse',
  full_name='wireless_android_skyjam.GetArtistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artist', full_name='wireless_android_skyjam.GetArtistsResponse.artist', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12868,
  serialized_end=12937,
)


_MUSICGENRE = _descriptor.Descriptor(
  name='MusicGenre',
  full_name='wireless_android_skyjam.MusicGenre',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='wireless_android_skyjam.MusicGenre.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_track_count', full_name='wireless_android_skyjam.MusicGenre.total_track_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album', full_name='wireless_android_skyjam.MusicGenre.album', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12939,
  serialized_end=13039,
)


_GENRESORTORDER = _descriptor.Descriptor(
  name='GenreSortOrder',
  full_name='wireless_android_skyjam.GenreSortOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='descending', full_name='wireless_android_skyjam.GenreSortOrder.descending', index=0,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13041,
  serialized_end=13084,
)


_GETGENRESREQUEST = _descriptor.Descriptor(
  name='GetGenresRequest',
  full_name='wireless_android_skyjam.GetGenresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetGenresRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='wireless_android_skyjam.GetGenresRequest.sort_order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetGenresRequest.max_results', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13086,
  serialized_end=13203,
)


_GETGENRESRESPONSE = _descriptor.Descriptor(
  name='GetGenresResponse',
  full_name='wireless_android_skyjam.GetGenresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='genre', full_name='wireless_android_skyjam.GetGenresResponse.genre', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13205,
  serialized_end=13276,
)


_GETDYNAMICPLAYLISTENTRIESREQUEST = _descriptor.Descriptor(
  name='GetDynamicPlaylistEntriesRequest',
  full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entries_type', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.playlist_entries_type', index=1,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.max_results', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.continuation_token', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='include_all_track_metadata', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesRequest.include_all_track_metadata', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETDYNAMICPLAYLISTENTRIESREQUEST_DYNAMICPLAYLISTENTRIESTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13279,
  serialized_end=13661,
)


_GETDYNAMICPLAYLISTENTRIESRESPONSE = _descriptor.Descriptor(
  name='GetDynamicPlaylistEntriesResponse',
  full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entry', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.playlist_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimated_total_results', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.estimated_total_results', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='continuation_token', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.continuation_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='playlist_entries_type', full_name='wireless_android_skyjam.GetDynamicPlaylistEntriesResponse.playlist_entries_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETDYNAMICPLAYLISTENTRIESRESPONSE_DYNAMICPLAYLISTENTRIESTYPE,
    _GETDYNAMICPLAYLISTENTRIESRESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13664,
  serialized_end=14210,
)


_GETAGGREGATIONSBYTRACKTYPEREQUEST = _descriptor.Descriptor(
  name='GetAggregationsByTrackTypeRequest',
  full_name='wireless_android_skyjam.GetAggregationsByTrackTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetAggregationsByTrackTypeRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14212,
  serialized_end=14264,
)


_TRACKTYPEAGGREGATE = _descriptor.Descriptor(
  name='TrackTypeAggregate',
  full_name='wireless_android_skyjam.TrackTypeAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='track_type_value', full_name='wireless_android_skyjam.TrackTypeAggregate.track_type_value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='wireless_android_skyjam.TrackTypeAggregate.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKTYPEAGGREGATE_TRACKTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14267,
  serialized_end=14525,
)


_GETAGGREGATIONSBYTRACKTYPERESPONSE = _descriptor.Descriptor(
  name='GetAggregationsByTrackTypeResponse',
  full_name='wireless_android_skyjam.GetAggregationsByTrackTypeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='track_type_aggregate', full_name='wireless_android_skyjam.GetAggregationsByTrackTypeResponse.track_type_aggregate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14527,
  serialized_end=14638,
)


_GETAGGREGATIONSBYAVAILABILITYSTATUSREQUEST = _descriptor.Descriptor(
  name='GetAggregationsByAvailabilityStatusRequest',
  full_name='wireless_android_skyjam.GetAggregationsByAvailabilityStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetAggregationsByAvailabilityStatusRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14640,
  serialized_end=14701,
)


_AVAILABILITYSTATUSAGGREGATE = _descriptor.Descriptor(
  name='AvailabilityStatusAggregate',
  full_name='wireless_android_skyjam.AvailabilityStatusAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='availability_status', full_name='wireless_android_skyjam.AvailabilityStatusAggregate.availability_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='wireless_android_skyjam.AvailabilityStatusAggregate.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AVAILABILITYSTATUSAGGREGATE_AVAILABILITYSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14704,
  serialized_end=14987,
)


_GETAGGREGATIONSBYAVAILABILITYSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetAggregationsByAvailabilityStatusResponse',
  full_name='wireless_android_skyjam.GetAggregationsByAvailabilityStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='availability_status_aggregate', full_name='wireless_android_skyjam.GetAggregationsByAvailabilityStatusResponse.availability_status_aggregate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14990,
  serialized_end=15128,
)


_ADDPROMOTRACKSREQUEST = _descriptor.Descriptor(
  name='AddPromoTracksRequest',
  full_name='wireless_android_skyjam.AddPromoTracksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.AddPromoTracksRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='genre', full_name='wireless_android_skyjam.AddPromoTracksRequest.genre', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15130,
  serialized_end=15185,
)


_ADDPROMOTRACKSRESPONSE = _descriptor.Descriptor(
  name='AddPromoTracksResponse',
  full_name='wireless_android_skyjam.AddPromoTracksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='track', full_name='wireless_android_skyjam.AddPromoTracksResponse.track', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15187,
  serialized_end=15258,
)


_GETPLAYLISTAGGREGATIONSREQUEST = _descriptor.Descriptor(
  name='GetPlaylistAggregationsRequest',
  full_name='wireless_android_skyjam.GetPlaylistAggregationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.GetPlaylistAggregationsRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='wireless_android_skyjam.GetPlaylistAggregationsRequest.max_results', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=14,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15260,
  serialized_end=15334,
)


_PLAYLISTAGGREGATE = _descriptor.Descriptor(
  name='PlaylistAggregate',
  full_name='wireless_android_skyjam.PlaylistAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='playlist_id', full_name='wireless_android_skyjam.PlaylistAggregate.playlist_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='wireless_android_skyjam.PlaylistAggregate.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='album_art', full_name='wireless_android_skyjam.PlaylistAggregate.album_art', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='track_count', full_name='wireless_android_skyjam.PlaylistAggregate.track_count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_time_played', full_name='wireless_android_skyjam.PlaylistAggregate.last_time_played', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15337,
  serialized_end=15492,
)


_GETPLAYLISTAGGREGATIONSRESPONSE = _descriptor.Descriptor(
  name='GetPlaylistAggregationsResponse',
  full_name='wireless_android_skyjam.GetPlaylistAggregationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='playlist_aggregate', full_name='wireless_android_skyjam.GetPlaylistAggregationsResponse.playlist_aggregate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15494,
  serialized_end=15599,
)


_REMOTECONTROLCOMMANDREQUEST = _descriptor.Descriptor(
  name='RemoteControlCommandRequest',
  full_name='wireless_android_skyjam.RemoteControlCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaia_id', full_name='wireless_android_skyjam.RemoteControlCommandRequest.gaia_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='wireless_android_skyjam.RemoteControlCommandRequest.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15601,
  serialized_end=15664,
)


_REMOTECONTROLCOMMANDRESPONSE = _descriptor.Descriptor(
  name='RemoteControlCommandResponse',
  full_name='wireless_android_skyjam.RemoteControlCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_code', full_name='wireless_android_skyjam.RemoteControlCommandResponse.response_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REMOTECONTROLCOMMANDRESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15667,
  serialized_end=15870,
)

_AUDIOREF.fields_by_name['store'].enum_type = _AUDIOREF_STORE
_AUDIOREF_STORE.containing_type = _AUDIOREF
_IMAGEREF.fields_by_name['store'].enum_type = _IMAGEREF_STORE
_IMAGEREF.fields_by_name['origin'].enum_type = _IMAGEREF_ORIGIN
_IMAGEREF_STORE.containing_type = _IMAGEREF
_IMAGEREF_ORIGIN.containing_type = _IMAGEREF
_TRACKEXTRAS.fields_by_name['additional_metadata'].message_type = _ADDITIONALMETADATA
_TRACK.fields_by_name['audio_ref'].message_type = _AUDIOREF
_TRACK.fields_by_name['album_art_ref'].message_type = _IMAGEREF
_TRACK.fields_by_name['availability_status'].enum_type = _TRACK_AVAILABILITYSTATUS
_TRACK.fields_by_name['content_type'].enum_type = _TRACK_CONTENTTYPE
_TRACK.fields_by_name['channels'].enum_type = _TRACK_CHANNELS
_TRACK.fields_by_name['track_type'].enum_type = _TRACK_TRACKTYPE
_TRACK.fields_by_name['rating'].enum_type = _TRACK_RATING
_TRACK.fields_by_name['uits_metadata'].message_type = uits__pb2._UITSMETADATA
_TRACK.fields_by_name['original_content_type'].enum_type = _TRACK_CONTENTTYPE
_TRACK.fields_by_name['uploaded_uits'].message_type = _UPLOADEDUITSID3TAG
_TRACK.fields_by_name['explicit_type'].enum_type = _TRACK_EXPLICITTYPE
_TRACK.fields_by_name['track_extras'].message_type = _TRACKEXTRAS
_TRACK_AVAILABILITYSTATUS.containing_type = _TRACK
_TRACK_CONTENTTYPE.containing_type = _TRACK
_TRACK_CHANNELS.containing_type = _TRACK
_TRACK_TRACKTYPE.containing_type = _TRACK
_TRACK_RATING.containing_type = _TRACK
_TRACK_EXPLICITTYPE.containing_type = _TRACK
_TRACKS.fields_by_name['track'].message_type = _TRACK
_PLAYLIST.fields_by_name['playlist_type'].enum_type = _PLAYLIST_PLAYLISTTYPE
_PLAYLIST.fields_by_name['playlist_art_ref'].message_type = _IMAGEREF
_PLAYLIST_PLAYLISTTYPE.containing_type = _PLAYLIST
_PLAYLISTENTRY.fields_by_name['relative_position_id_type'].enum_type = _PLAYLISTENTRY_RELATIVEPOSITIONIDTYPE
_PLAYLISTENTRY.fields_by_name['track'].message_type = _TRACK
_PLAYLISTENTRY_RELATIVEPOSITIONIDTYPE.containing_type = _PLAYLISTENTRY
_TRACKSEARCHRESTRICTION.fields_by_name['attribute'].enum_type = _TRACKSEARCHRESTRICTION_TRACKATTRIBUTE
_TRACKSEARCHRESTRICTION.fields_by_name['comparison_type'].enum_type = _TRACKSEARCHRESTRICTION_COMPARISONTYPE
_TRACKSEARCHRESTRICTION_TRACKATTRIBUTE.containing_type = _TRACKSEARCHRESTRICTION
_TRACKSEARCHRESTRICTION_COMPARISONTYPE.containing_type = _TRACKSEARCHRESTRICTION
_TRACKSEARCHRESTRICTIONSET.fields_by_name['type'].enum_type = _TRACKSEARCHRESTRICTIONSET_RESTRICTIONSETTYPE
_TRACKSEARCHRESTRICTIONSET.fields_by_name['restriction'].message_type = _TRACKSEARCHRESTRICTION
_TRACKSEARCHRESTRICTIONSET.fields_by_name['sub_set'].message_type = _TRACKSEARCHRESTRICTIONSET
_TRACKSEARCHRESTRICTIONSET_RESTRICTIONSETTYPE.containing_type = _TRACKSEARCHRESTRICTIONSET
_TRACKSORTORDER.fields_by_name['attribute'].enum_type = _TRACKSORTORDER_TRACKATTRIBUTE
_TRACKSORTORDER_TRACKATTRIBUTE.containing_type = _TRACKSORTORDER
_GETTRACKSREQUEST.fields_by_name['search_restriction'].message_type = _TRACKSEARCHRESTRICTION
_GETTRACKSREQUEST.fields_by_name['sort_order'].message_type = _TRACKSORTORDER
_GETTRACKSREQUEST.fields_by_name['restriction_set'].message_type = _TRACKSEARCHRESTRICTIONSET
_GETTRACKSREQUEST.fields_by_name['track_projection'].enum_type = _GETTRACKSREQUEST_TRACKPROJECTION
_GETTRACKSREQUEST_TRACKPROJECTION.containing_type = _GETTRACKSREQUEST
_GETTRACKSRESPONSE.fields_by_name['response_code'].enum_type = _GETTRACKSRESPONSE_RESPONSECODE
_GETTRACKSRESPONSE.fields_by_name['track'].message_type = _TRACK
_GETTRACKSRESPONSE_RESPONSECODE.containing_type = _GETTRACKSRESPONSE
_GETPLAYLISTENTRIESRESPONSE.fields_by_name['response_code'].enum_type = _GETPLAYLISTENTRIESRESPONSE_RESPONSECODE
_GETPLAYLISTENTRIESRESPONSE.fields_by_name['playlist_entry'].message_type = _PLAYLISTENTRY
_GETPLAYLISTENTRIESRESPONSE_RESPONSECODE.containing_type = _GETPLAYLISTENTRIESRESPONSE
_PLAYLISTSORTORDER.fields_by_name['attribute'].enum_type = _PLAYLISTSORTORDER_PLAYLISTATTRIBUTE
_PLAYLISTSORTORDER_PLAYLISTATTRIBUTE.containing_type = _PLAYLISTSORTORDER
_GETPLAYLISTSREQUEST.fields_by_name['sort_order'].message_type = _PLAYLISTSORTORDER
_GETPLAYLISTSRESPONSE.fields_by_name['response_code'].enum_type = _GETPLAYLISTSRESPONSE_RESPONSECODE
_GETPLAYLISTSRESPONSE.fields_by_name['playlist'].message_type = _PLAYLIST
_GETPLAYLISTSRESPONSE_RESPONSECODE.containing_type = _GETPLAYLISTSRESPONSE
_BATCHLOOKUPREQUEST.fields_by_name['track'].message_type = _LOOKUPTRACKREQUEST
_BATCHLOOKUPREQUEST.fields_by_name['playlist'].message_type = _LOOKUPPLAYLISTREQUEST
_BATCHLOOKUPREQUEST.fields_by_name['metadata_type'].enum_type = _BATCHLOOKUPREQUEST_METADATATYPE
_BATCHLOOKUPREQUEST.fields_by_name['playlist_entry'].message_type = _LOOKUPPLAYLISTENTRYREQUEST
_BATCHLOOKUPREQUEST_METADATATYPE.containing_type = _BATCHLOOKUPREQUEST
_BATCHLOOKUPRESPONSE.fields_by_name['track'].message_type = _TRACK
_BATCHLOOKUPRESPONSE.fields_by_name['playlist'].message_type = _PLAYLIST
_BATCHLOOKUPRESPONSE.fields_by_name['playlist_entry'].message_type = _PLAYLISTENTRY
_MUTATETRACKREQUEST.fields_by_name['create_track'].message_type = _TRACK
_MUTATETRACKREQUEST.fields_by_name['update_track'].message_type = _TRACK
_MUTATERESPONSE.fields_by_name['response_code'].enum_type = _MUTATERESPONSE_MUTATERESPONSECODE
_MUTATERESPONSE.fields_by_name['availability_status'].enum_type = _MUTATERESPONSE_AVAILABILITYSTATUS
_MUTATERESPONSE_MUTATERESPONSECODE.containing_type = _MUTATERESPONSE
_MUTATERESPONSE_AVAILABILITYSTATUS.containing_type = _MUTATERESPONSE
_BATCHMUTATETRACKSREQUEST.fields_by_name['track_mutation'].message_type = _MUTATETRACKREQUEST
_BATCHMUTATETRACKSRESPONSE.fields_by_name['response_code'].enum_type = _BATCHMUTATETRACKSRESPONSE_BATCHMUTATETRACKSRESPONSECODE
_BATCHMUTATETRACKSRESPONSE.fields_by_name['mutate_response'].message_type = _MUTATERESPONSE
_BATCHMUTATETRACKSRESPONSE_BATCHMUTATETRACKSRESPONSECODE.containing_type = _BATCHMUTATETRACKSRESPONSE
_MUTATEPLAYLISTREQUEST.fields_by_name['create_playlist'].message_type = _PLAYLIST
_MUTATEPLAYLISTREQUEST.fields_by_name['update_playlist'].message_type = _PLAYLIST
_MUTATEPLAYLISTREQUEST.fields_by_name['playlist_entry'].message_type = _PLAYLISTENTRY
_BATCHMUTATEPLAYLISTSREQUEST.fields_by_name['playlist_mutation'].message_type = _MUTATEPLAYLISTREQUEST
_BATCHMUTATEPLAYLISTSRESPONSE.fields_by_name['response_code'].enum_type = _BATCHMUTATEPLAYLISTSRESPONSE_BATCHMUTATEPLAYLISTSRESPONSECODE
_BATCHMUTATEPLAYLISTSRESPONSE.fields_by_name['mutate_response'].message_type = _MUTATERESPONSE
_BATCHMUTATEPLAYLISTSRESPONSE_BATCHMUTATEPLAYLISTSRESPONSECODE.containing_type = _BATCHMUTATEPLAYLISTSRESPONSE
_MUTATEPLAYLISTENTRYREQUEST.fields_by_name['create_playlist_entry'].message_type = _PLAYLISTENTRY
_MUTATEPLAYLISTENTRYREQUEST.fields_by_name['update_playlist_entry'].message_type = _PLAYLISTENTRY
_MUTATEPLAYLISTENTRYREQUEST.fields_by_name['delete_playlist_entry'].message_type = _PLAYLISTENTRY
_BATCHMUTATEPLAYLISTENTRIESREQUEST.fields_by_name['playlist_entry_mutation'].message_type = _MUTATEPLAYLISTENTRYREQUEST
_BATCHMUTATEPLAYLISTENTRIESRESPONSE.fields_by_name['response_code'].enum_type = _BATCHMUTATEPLAYLISTENTRIESRESPONSE_BATCHMUTATEPLAYLISTENTRIESRESPONSECODE
_BATCHMUTATEPLAYLISTENTRIESRESPONSE.fields_by_name['mutate_response'].message_type = _MUTATERESPONSE
_BATCHMUTATEPLAYLISTENTRIESRESPONSE_BATCHMUTATEPLAYLISTENTRIESRESPONSECODE.containing_type = _BATCHMUTATEPLAYLISTENTRIESRESPONSE
_MAGICPLAYLISTSEED.fields_by_name['seed_type'].enum_type = _MAGICPLAYLISTSEED_SEEDTYPE
_MAGICPLAYLISTSEED_SEEDTYPE.containing_type = _MAGICPLAYLISTSEED
_MAGICPLAYLISTREQUEST.fields_by_name['seed'].message_type = _MAGICPLAYLISTSEED
_MAGICPLAYLISTRESPONSE.fields_by_name['playlist'].message_type = _PLAYLIST
_MAGICPLAYLISTRESPONSE.fields_by_name['playlist_entry'].message_type = _PLAYLISTENTRY
_ALBUM.fields_by_name['album_art'].message_type = _IMAGEREF
_ALBUMSORTORDER.fields_by_name['attribute'].enum_type = _ALBUMSORTORDER_ALBUMATTRIBUTE
_ALBUMSORTORDER_ALBUMATTRIBUTE.containing_type = _ALBUMSORTORDER
_GETALBUMSREQUEST.fields_by_name['sort_order'].message_type = _ALBUMSORTORDER
_GETALBUMSRESPONSE.fields_by_name['album'].message_type = _ALBUM
_ARTIST.fields_by_name['album'].message_type = _ALBUM
_GETARTISTSREQUEST.fields_by_name['sort_order'].message_type = _ARTISTSORTORDER
_GETARTISTSRESPONSE.fields_by_name['artist'].message_type = _ARTIST
_MUSICGENRE.fields_by_name['album'].message_type = _ALBUM
_GETGENRESREQUEST.fields_by_name['sort_order'].message_type = _GENRESORTORDER
_GETGENRESRESPONSE.fields_by_name['genre'].message_type = _MUSICGENRE
_GETDYNAMICPLAYLISTENTRIESREQUEST.fields_by_name['playlist_entries_type'].enum_type = _GETDYNAMICPLAYLISTENTRIESREQUEST_DYNAMICPLAYLISTENTRIESTYPE
_GETDYNAMICPLAYLISTENTRIESREQUEST_DYNAMICPLAYLISTENTRIESTYPE.containing_type = _GETDYNAMICPLAYLISTENTRIESREQUEST
_GETDYNAMICPLAYLISTENTRIESRESPONSE.fields_by_name['response_code'].enum_type = _GETDYNAMICPLAYLISTENTRIESRESPONSE_RESPONSECODE
_GETDYNAMICPLAYLISTENTRIESRESPONSE.fields_by_name['playlist_entry'].message_type = _PLAYLISTENTRY
_GETDYNAMICPLAYLISTENTRIESRESPONSE.fields_by_name['playlist_entries_type'].enum_type = _GETDYNAMICPLAYLISTENTRIESRESPONSE_DYNAMICPLAYLISTENTRIESTYPE
_GETDYNAMICPLAYLISTENTRIESRESPONSE_DYNAMICPLAYLISTENTRIESTYPE.containing_type = _GETDYNAMICPLAYLISTENTRIESRESPONSE
_GETDYNAMICPLAYLISTENTRIESRESPONSE_RESPONSECODE.containing_type = _GETDYNAMICPLAYLISTENTRIESRESPONSE
_TRACKTYPEAGGREGATE.fields_by_name['track_type_value'].enum_type = _TRACKTYPEAGGREGATE_TRACKTYPE
_TRACKTYPEAGGREGATE_TRACKTYPE.containing_type = _TRACKTYPEAGGREGATE
_GETAGGREGATIONSBYTRACKTYPERESPONSE.fields_by_name['track_type_aggregate'].message_type = _TRACKTYPEAGGREGATE
_AVAILABILITYSTATUSAGGREGATE.fields_by_name['availability_status'].enum_type = _AVAILABILITYSTATUSAGGREGATE_AVAILABILITYSTATUS
_AVAILABILITYSTATUSAGGREGATE_AVAILABILITYSTATUS.containing_type = _AVAILABILITYSTATUSAGGREGATE
_GETAGGREGATIONSBYAVAILABILITYSTATUSRESPONSE.fields_by_name['availability_status_aggregate'].message_type = _AVAILABILITYSTATUSAGGREGATE
_ADDPROMOTRACKSRESPONSE.fields_by_name['track'].message_type = _TRACK
_PLAYLISTAGGREGATE.fields_by_name['album_art'].message_type = _IMAGEREF
_GETPLAYLISTAGGREGATIONSRESPONSE.fields_by_name['playlist_aggregate'].message_type = _PLAYLISTAGGREGATE
_REMOTECONTROLCOMMANDRESPONSE.fields_by_name['response_code'].enum_type = _REMOTECONTROLCOMMANDRESPONSE_RESPONSECODE
_REMOTECONTROLCOMMANDRESPONSE_RESPONSECODE.containing_type = _REMOTECONTROLCOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['AudioRef'] = _AUDIOREF
DESCRIPTOR.message_types_by_name['ImageRef'] = _IMAGEREF
DESCRIPTOR.message_types_by_name['UploadedUitsId3Tag'] = _UPLOADEDUITSID3TAG
DESCRIPTOR.message_types_by_name['AdditionalMetadata'] = _ADDITIONALMETADATA
DESCRIPTOR.message_types_by_name['TrackExtras'] = _TRACKEXTRAS
DESCRIPTOR.message_types_by_name['Track'] = _TRACK
DESCRIPTOR.message_types_by_name['Tracks'] = _TRACKS
DESCRIPTOR.message_types_by_name['Playlist'] = _PLAYLIST
DESCRIPTOR.message_types_by_name['PlaylistEntry'] = _PLAYLISTENTRY
DESCRIPTOR.message_types_by_name['TrackSearchRestriction'] = _TRACKSEARCHRESTRICTION
DESCRIPTOR.message_types_by_name['TrackSearchRestrictionSet'] = _TRACKSEARCHRESTRICTIONSET
DESCRIPTOR.message_types_by_name['TrackSortOrder'] = _TRACKSORTORDER
DESCRIPTOR.message_types_by_name['GetTracksRequest'] = _GETTRACKSREQUEST
DESCRIPTOR.message_types_by_name['GetTracksResponse'] = _GETTRACKSRESPONSE
DESCRIPTOR.message_types_by_name['GetPlaylistEntriesRequest'] = _GETPLAYLISTENTRIESREQUEST
DESCRIPTOR.message_types_by_name['GetPlaylistEntriesResponse'] = _GETPLAYLISTENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['PlaylistSortOrder'] = _PLAYLISTSORTORDER
DESCRIPTOR.message_types_by_name['GetPlaylistsRequest'] = _GETPLAYLISTSREQUEST
DESCRIPTOR.message_types_by_name['GetPlaylistsResponse'] = _GETPLAYLISTSRESPONSE
DESCRIPTOR.message_types_by_name['LookupTrackRequest'] = _LOOKUPTRACKREQUEST
DESCRIPTOR.message_types_by_name['LookupPlaylistEntryRequest'] = _LOOKUPPLAYLISTENTRYREQUEST
DESCRIPTOR.message_types_by_name['LookupPlaylistRequest'] = _LOOKUPPLAYLISTREQUEST
DESCRIPTOR.message_types_by_name['BatchLookupRequest'] = _BATCHLOOKUPREQUEST
DESCRIPTOR.message_types_by_name['BatchLookupResponse'] = _BATCHLOOKUPRESPONSE
DESCRIPTOR.message_types_by_name['MutateTrackRequest'] = _MUTATETRACKREQUEST
DESCRIPTOR.message_types_by_name['MutateResponse'] = _MUTATERESPONSE
DESCRIPTOR.message_types_by_name['BatchMutateTracksRequest'] = _BATCHMUTATETRACKSREQUEST
DESCRIPTOR.message_types_by_name['BatchMutateTracksResponse'] = _BATCHMUTATETRACKSRESPONSE
DESCRIPTOR.message_types_by_name['MutatePlaylistRequest'] = _MUTATEPLAYLISTREQUEST
DESCRIPTOR.message_types_by_name['BatchMutatePlaylistsRequest'] = _BATCHMUTATEPLAYLISTSREQUEST
DESCRIPTOR.message_types_by_name['BatchMutatePlaylistsResponse'] = _BATCHMUTATEPLAYLISTSRESPONSE
DESCRIPTOR.message_types_by_name['MutatePlaylistEntryRequest'] = _MUTATEPLAYLISTENTRYREQUEST
DESCRIPTOR.message_types_by_name['BatchMutatePlaylistEntriesRequest'] = _BATCHMUTATEPLAYLISTENTRIESREQUEST
DESCRIPTOR.message_types_by_name['BatchMutatePlaylistEntriesResponse'] = _BATCHMUTATEPLAYLISTENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['MagicPlaylistSeed'] = _MAGICPLAYLISTSEED
DESCRIPTOR.message_types_by_name['MagicPlaylistRequest'] = _MAGICPLAYLISTREQUEST
DESCRIPTOR.message_types_by_name['MagicPlaylistResponse'] = _MAGICPLAYLISTRESPONSE
DESCRIPTOR.message_types_by_name['FlushLockerRequest'] = _FLUSHLOCKERREQUEST
DESCRIPTOR.message_types_by_name['FlushLockerResponse'] = _FLUSHLOCKERRESPONSE
DESCRIPTOR.message_types_by_name['LockerNotification'] = _LOCKERNOTIFICATION
DESCRIPTOR.message_types_by_name['Album'] = _ALBUM
DESCRIPTOR.message_types_by_name['AlbumSortOrder'] = _ALBUMSORTORDER
DESCRIPTOR.message_types_by_name['GetAlbumsRequest'] = _GETALBUMSREQUEST
DESCRIPTOR.message_types_by_name['GetAlbumsResponse'] = _GETALBUMSRESPONSE
DESCRIPTOR.message_types_by_name['Artist'] = _ARTIST
DESCRIPTOR.message_types_by_name['ArtistSortOrder'] = _ARTISTSORTORDER
DESCRIPTOR.message_types_by_name['GetArtistsRequest'] = _GETARTISTSREQUEST
DESCRIPTOR.message_types_by_name['GetArtistsResponse'] = _GETARTISTSRESPONSE
DESCRIPTOR.message_types_by_name['MusicGenre'] = _MUSICGENRE
DESCRIPTOR.message_types_by_name['GenreSortOrder'] = _GENRESORTORDER
DESCRIPTOR.message_types_by_name['GetGenresRequest'] = _GETGENRESREQUEST
DESCRIPTOR.message_types_by_name['GetGenresResponse'] = _GETGENRESRESPONSE
DESCRIPTOR.message_types_by_name['GetDynamicPlaylistEntriesRequest'] = _GETDYNAMICPLAYLISTENTRIESREQUEST
DESCRIPTOR.message_types_by_name['GetDynamicPlaylistEntriesResponse'] = _GETDYNAMICPLAYLISTENTRIESRESPONSE
DESCRIPTOR.message_types_by_name['GetAggregationsByTrackTypeRequest'] = _GETAGGREGATIONSBYTRACKTYPEREQUEST
DESCRIPTOR.message_types_by_name['TrackTypeAggregate'] = _TRACKTYPEAGGREGATE
DESCRIPTOR.message_types_by_name['GetAggregationsByTrackTypeResponse'] = _GETAGGREGATIONSBYTRACKTYPERESPONSE
DESCRIPTOR.message_types_by_name['GetAggregationsByAvailabilityStatusRequest'] = _GETAGGREGATIONSBYAVAILABILITYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['AvailabilityStatusAggregate'] = _AVAILABILITYSTATUSAGGREGATE
DESCRIPTOR.message_types_by_name['GetAggregationsByAvailabilityStatusResponse'] = _GETAGGREGATIONSBYAVAILABILITYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['AddPromoTracksRequest'] = _ADDPROMOTRACKSREQUEST
DESCRIPTOR.message_types_by_name['AddPromoTracksResponse'] = _ADDPROMOTRACKSRESPONSE
DESCRIPTOR.message_types_by_name['GetPlaylistAggregationsRequest'] = _GETPLAYLISTAGGREGATIONSREQUEST
DESCRIPTOR.message_types_by_name['PlaylistAggregate'] = _PLAYLISTAGGREGATE
DESCRIPTOR.message_types_by_name['GetPlaylistAggregationsResponse'] = _GETPLAYLISTAGGREGATIONSRESPONSE
DESCRIPTOR.message_types_by_name['RemoteControlCommandRequest'] = _REMOTECONTROLCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['RemoteControlCommandResponse'] = _REMOTECONTROLCOMMANDRESPONSE

AudioRef = _reflection.GeneratedProtocolMessageType('AudioRef', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOREF,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AudioRef)
  ))
_sym_db.RegisterMessage(AudioRef)

ImageRef = _reflection.GeneratedProtocolMessageType('ImageRef', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEREF,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.ImageRef)
  ))
_sym_db.RegisterMessage(ImageRef)

UploadedUitsId3Tag = _reflection.GeneratedProtocolMessageType('UploadedUitsId3Tag', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADEDUITSID3TAG,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.UploadedUitsId3Tag)
  ))
_sym_db.RegisterMessage(UploadedUitsId3Tag)

AdditionalMetadata = _reflection.GeneratedProtocolMessageType('AdditionalMetadata', (_message.Message,), dict(
  DESCRIPTOR = _ADDITIONALMETADATA,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AdditionalMetadata)
  ))
_sym_db.RegisterMessage(AdditionalMetadata)

TrackExtras = _reflection.GeneratedProtocolMessageType('TrackExtras', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEXTRAS,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.TrackExtras)
  ))
_sym_db.RegisterMessage(TrackExtras)

Track = _reflection.GeneratedProtocolMessageType('Track', (_message.Message,), dict(
  DESCRIPTOR = _TRACK,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.Track)
  ))
_sym_db.RegisterMessage(Track)

Tracks = _reflection.GeneratedProtocolMessageType('Tracks', (_message.Message,), dict(
  DESCRIPTOR = _TRACKS,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.Tracks)
  ))
_sym_db.RegisterMessage(Tracks)

Playlist = _reflection.GeneratedProtocolMessageType('Playlist', (_message.Message,), dict(
  DESCRIPTOR = _PLAYLIST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.Playlist)
  ))
_sym_db.RegisterMessage(Playlist)

PlaylistEntry = _reflection.GeneratedProtocolMessageType('PlaylistEntry', (_message.Message,), dict(
  DESCRIPTOR = _PLAYLISTENTRY,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.PlaylistEntry)
  ))
_sym_db.RegisterMessage(PlaylistEntry)

TrackSearchRestriction = _reflection.GeneratedProtocolMessageType('TrackSearchRestriction', (_message.Message,), dict(
  DESCRIPTOR = _TRACKSEARCHRESTRICTION,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.TrackSearchRestriction)
  ))
_sym_db.RegisterMessage(TrackSearchRestriction)

TrackSearchRestrictionSet = _reflection.GeneratedProtocolMessageType('TrackSearchRestrictionSet', (_message.Message,), dict(
  DESCRIPTOR = _TRACKSEARCHRESTRICTIONSET,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.TrackSearchRestrictionSet)
  ))
_sym_db.RegisterMessage(TrackSearchRestrictionSet)

TrackSortOrder = _reflection.GeneratedProtocolMessageType('TrackSortOrder', (_message.Message,), dict(
  DESCRIPTOR = _TRACKSORTORDER,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.TrackSortOrder)
  ))
_sym_db.RegisterMessage(TrackSortOrder)

GetTracksRequest = _reflection.GeneratedProtocolMessageType('GetTracksRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTRACKSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetTracksRequest)
  ))
_sym_db.RegisterMessage(GetTracksRequest)

GetTracksResponse = _reflection.GeneratedProtocolMessageType('GetTracksResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTRACKSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetTracksResponse)
  ))
_sym_db.RegisterMessage(GetTracksResponse)

GetPlaylistEntriesRequest = _reflection.GeneratedProtocolMessageType('GetPlaylistEntriesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTENTRIESREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistEntriesRequest)
  ))
_sym_db.RegisterMessage(GetPlaylistEntriesRequest)

GetPlaylistEntriesResponse = _reflection.GeneratedProtocolMessageType('GetPlaylistEntriesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTENTRIESRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistEntriesResponse)
  ))
_sym_db.RegisterMessage(GetPlaylistEntriesResponse)

PlaylistSortOrder = _reflection.GeneratedProtocolMessageType('PlaylistSortOrder', (_message.Message,), dict(
  DESCRIPTOR = _PLAYLISTSORTORDER,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.PlaylistSortOrder)
  ))
_sym_db.RegisterMessage(PlaylistSortOrder)

GetPlaylistsRequest = _reflection.GeneratedProtocolMessageType('GetPlaylistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistsRequest)
  ))
_sym_db.RegisterMessage(GetPlaylistsRequest)

GetPlaylistsResponse = _reflection.GeneratedProtocolMessageType('GetPlaylistsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistsResponse)
  ))
_sym_db.RegisterMessage(GetPlaylistsResponse)

LookupTrackRequest = _reflection.GeneratedProtocolMessageType('LookupTrackRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPTRACKREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.LookupTrackRequest)
  ))
_sym_db.RegisterMessage(LookupTrackRequest)

LookupPlaylistEntryRequest = _reflection.GeneratedProtocolMessageType('LookupPlaylistEntryRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPPLAYLISTENTRYREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.LookupPlaylistEntryRequest)
  ))
_sym_db.RegisterMessage(LookupPlaylistEntryRequest)

LookupPlaylistRequest = _reflection.GeneratedProtocolMessageType('LookupPlaylistRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPPLAYLISTREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.LookupPlaylistRequest)
  ))
_sym_db.RegisterMessage(LookupPlaylistRequest)

BatchLookupRequest = _reflection.GeneratedProtocolMessageType('BatchLookupRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHLOOKUPREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchLookupRequest)
  ))
_sym_db.RegisterMessage(BatchLookupRequest)

BatchLookupResponse = _reflection.GeneratedProtocolMessageType('BatchLookupResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHLOOKUPRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchLookupResponse)
  ))
_sym_db.RegisterMessage(BatchLookupResponse)

MutateTrackRequest = _reflection.GeneratedProtocolMessageType('MutateTrackRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATETRACKREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MutateTrackRequest)
  ))
_sym_db.RegisterMessage(MutateTrackRequest)

MutateResponse = _reflection.GeneratedProtocolMessageType('MutateResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATERESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MutateResponse)
  ))
_sym_db.RegisterMessage(MutateResponse)

BatchMutateTracksRequest = _reflection.GeneratedProtocolMessageType('BatchMutateTracksRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATETRACKSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutateTracksRequest)
  ))
_sym_db.RegisterMessage(BatchMutateTracksRequest)

BatchMutateTracksResponse = _reflection.GeneratedProtocolMessageType('BatchMutateTracksResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATETRACKSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutateTracksResponse)
  ))
_sym_db.RegisterMessage(BatchMutateTracksResponse)

MutatePlaylistRequest = _reflection.GeneratedProtocolMessageType('MutatePlaylistRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEPLAYLISTREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MutatePlaylistRequest)
  ))
_sym_db.RegisterMessage(MutatePlaylistRequest)

BatchMutatePlaylistsRequest = _reflection.GeneratedProtocolMessageType('BatchMutatePlaylistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATEPLAYLISTSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutatePlaylistsRequest)
  ))
_sym_db.RegisterMessage(BatchMutatePlaylistsRequest)

BatchMutatePlaylistsResponse = _reflection.GeneratedProtocolMessageType('BatchMutatePlaylistsResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATEPLAYLISTSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutatePlaylistsResponse)
  ))
_sym_db.RegisterMessage(BatchMutatePlaylistsResponse)

MutatePlaylistEntryRequest = _reflection.GeneratedProtocolMessageType('MutatePlaylistEntryRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEPLAYLISTENTRYREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MutatePlaylistEntryRequest)
  ))
_sym_db.RegisterMessage(MutatePlaylistEntryRequest)

BatchMutatePlaylistEntriesRequest = _reflection.GeneratedProtocolMessageType('BatchMutatePlaylistEntriesRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATEPLAYLISTENTRIESREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutatePlaylistEntriesRequest)
  ))
_sym_db.RegisterMessage(BatchMutatePlaylistEntriesRequest)

BatchMutatePlaylistEntriesResponse = _reflection.GeneratedProtocolMessageType('BatchMutatePlaylistEntriesResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHMUTATEPLAYLISTENTRIESRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.BatchMutatePlaylistEntriesResponse)
  ))
_sym_db.RegisterMessage(BatchMutatePlaylistEntriesResponse)

MagicPlaylistSeed = _reflection.GeneratedProtocolMessageType('MagicPlaylistSeed', (_message.Message,), dict(
  DESCRIPTOR = _MAGICPLAYLISTSEED,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MagicPlaylistSeed)
  ))
_sym_db.RegisterMessage(MagicPlaylistSeed)

MagicPlaylistRequest = _reflection.GeneratedProtocolMessageType('MagicPlaylistRequest', (_message.Message,), dict(
  DESCRIPTOR = _MAGICPLAYLISTREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MagicPlaylistRequest)
  ))
_sym_db.RegisterMessage(MagicPlaylistRequest)

MagicPlaylistResponse = _reflection.GeneratedProtocolMessageType('MagicPlaylistResponse', (_message.Message,), dict(
  DESCRIPTOR = _MAGICPLAYLISTRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MagicPlaylistResponse)
  ))
_sym_db.RegisterMessage(MagicPlaylistResponse)

FlushLockerRequest = _reflection.GeneratedProtocolMessageType('FlushLockerRequest', (_message.Message,), dict(
  DESCRIPTOR = _FLUSHLOCKERREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.FlushLockerRequest)
  ))
_sym_db.RegisterMessage(FlushLockerRequest)

FlushLockerResponse = _reflection.GeneratedProtocolMessageType('FlushLockerResponse', (_message.Message,), dict(
  DESCRIPTOR = _FLUSHLOCKERRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.FlushLockerResponse)
  ))
_sym_db.RegisterMessage(FlushLockerResponse)

LockerNotification = _reflection.GeneratedProtocolMessageType('LockerNotification', (_message.Message,), dict(
  DESCRIPTOR = _LOCKERNOTIFICATION,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.LockerNotification)
  ))
_sym_db.RegisterMessage(LockerNotification)

Album = _reflection.GeneratedProtocolMessageType('Album', (_message.Message,), dict(
  DESCRIPTOR = _ALBUM,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.Album)
  ))
_sym_db.RegisterMessage(Album)

AlbumSortOrder = _reflection.GeneratedProtocolMessageType('AlbumSortOrder', (_message.Message,), dict(
  DESCRIPTOR = _ALBUMSORTORDER,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AlbumSortOrder)
  ))
_sym_db.RegisterMessage(AlbumSortOrder)

GetAlbumsRequest = _reflection.GeneratedProtocolMessageType('GetAlbumsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETALBUMSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAlbumsRequest)
  ))
_sym_db.RegisterMessage(GetAlbumsRequest)

GetAlbumsResponse = _reflection.GeneratedProtocolMessageType('GetAlbumsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETALBUMSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAlbumsResponse)
  ))
_sym_db.RegisterMessage(GetAlbumsResponse)

Artist = _reflection.GeneratedProtocolMessageType('Artist', (_message.Message,), dict(
  DESCRIPTOR = _ARTIST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.Artist)
  ))
_sym_db.RegisterMessage(Artist)

ArtistSortOrder = _reflection.GeneratedProtocolMessageType('ArtistSortOrder', (_message.Message,), dict(
  DESCRIPTOR = _ARTISTSORTORDER,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.ArtistSortOrder)
  ))
_sym_db.RegisterMessage(ArtistSortOrder)

GetArtistsRequest = _reflection.GeneratedProtocolMessageType('GetArtistsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETARTISTSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetArtistsRequest)
  ))
_sym_db.RegisterMessage(GetArtistsRequest)

GetArtistsResponse = _reflection.GeneratedProtocolMessageType('GetArtistsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETARTISTSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetArtistsResponse)
  ))
_sym_db.RegisterMessage(GetArtistsResponse)

MusicGenre = _reflection.GeneratedProtocolMessageType('MusicGenre', (_message.Message,), dict(
  DESCRIPTOR = _MUSICGENRE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.MusicGenre)
  ))
_sym_db.RegisterMessage(MusicGenre)

GenreSortOrder = _reflection.GeneratedProtocolMessageType('GenreSortOrder', (_message.Message,), dict(
  DESCRIPTOR = _GENRESORTORDER,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GenreSortOrder)
  ))
_sym_db.RegisterMessage(GenreSortOrder)

GetGenresRequest = _reflection.GeneratedProtocolMessageType('GetGenresRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETGENRESREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetGenresRequest)
  ))
_sym_db.RegisterMessage(GetGenresRequest)

GetGenresResponse = _reflection.GeneratedProtocolMessageType('GetGenresResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGENRESRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetGenresResponse)
  ))
_sym_db.RegisterMessage(GetGenresResponse)

GetDynamicPlaylistEntriesRequest = _reflection.GeneratedProtocolMessageType('GetDynamicPlaylistEntriesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDYNAMICPLAYLISTENTRIESREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetDynamicPlaylistEntriesRequest)
  ))
_sym_db.RegisterMessage(GetDynamicPlaylistEntriesRequest)

GetDynamicPlaylistEntriesResponse = _reflection.GeneratedProtocolMessageType('GetDynamicPlaylistEntriesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDYNAMICPLAYLISTENTRIESRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetDynamicPlaylistEntriesResponse)
  ))
_sym_db.RegisterMessage(GetDynamicPlaylistEntriesResponse)

GetAggregationsByTrackTypeRequest = _reflection.GeneratedProtocolMessageType('GetAggregationsByTrackTypeRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETAGGREGATIONSBYTRACKTYPEREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAggregationsByTrackTypeRequest)
  ))
_sym_db.RegisterMessage(GetAggregationsByTrackTypeRequest)

TrackTypeAggregate = _reflection.GeneratedProtocolMessageType('TrackTypeAggregate', (_message.Message,), dict(
  DESCRIPTOR = _TRACKTYPEAGGREGATE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.TrackTypeAggregate)
  ))
_sym_db.RegisterMessage(TrackTypeAggregate)

GetAggregationsByTrackTypeResponse = _reflection.GeneratedProtocolMessageType('GetAggregationsByTrackTypeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETAGGREGATIONSBYTRACKTYPERESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAggregationsByTrackTypeResponse)
  ))
_sym_db.RegisterMessage(GetAggregationsByTrackTypeResponse)

GetAggregationsByAvailabilityStatusRequest = _reflection.GeneratedProtocolMessageType('GetAggregationsByAvailabilityStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETAGGREGATIONSBYAVAILABILITYSTATUSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAggregationsByAvailabilityStatusRequest)
  ))
_sym_db.RegisterMessage(GetAggregationsByAvailabilityStatusRequest)

AvailabilityStatusAggregate = _reflection.GeneratedProtocolMessageType('AvailabilityStatusAggregate', (_message.Message,), dict(
  DESCRIPTOR = _AVAILABILITYSTATUSAGGREGATE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AvailabilityStatusAggregate)
  ))
_sym_db.RegisterMessage(AvailabilityStatusAggregate)

GetAggregationsByAvailabilityStatusResponse = _reflection.GeneratedProtocolMessageType('GetAggregationsByAvailabilityStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETAGGREGATIONSBYAVAILABILITYSTATUSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetAggregationsByAvailabilityStatusResponse)
  ))
_sym_db.RegisterMessage(GetAggregationsByAvailabilityStatusResponse)

AddPromoTracksRequest = _reflection.GeneratedProtocolMessageType('AddPromoTracksRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDPROMOTRACKSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AddPromoTracksRequest)
  ))
_sym_db.RegisterMessage(AddPromoTracksRequest)

AddPromoTracksResponse = _reflection.GeneratedProtocolMessageType('AddPromoTracksResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDPROMOTRACKSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.AddPromoTracksResponse)
  ))
_sym_db.RegisterMessage(AddPromoTracksResponse)

GetPlaylistAggregationsRequest = _reflection.GeneratedProtocolMessageType('GetPlaylistAggregationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTAGGREGATIONSREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistAggregationsRequest)
  ))
_sym_db.RegisterMessage(GetPlaylistAggregationsRequest)

PlaylistAggregate = _reflection.GeneratedProtocolMessageType('PlaylistAggregate', (_message.Message,), dict(
  DESCRIPTOR = _PLAYLISTAGGREGATE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.PlaylistAggregate)
  ))
_sym_db.RegisterMessage(PlaylistAggregate)

GetPlaylistAggregationsResponse = _reflection.GeneratedProtocolMessageType('GetPlaylistAggregationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETPLAYLISTAGGREGATIONSRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.GetPlaylistAggregationsResponse)
  ))
_sym_db.RegisterMessage(GetPlaylistAggregationsResponse)

RemoteControlCommandRequest = _reflection.GeneratedProtocolMessageType('RemoteControlCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOTECONTROLCOMMANDREQUEST,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.RemoteControlCommandRequest)
  ))
_sym_db.RegisterMessage(RemoteControlCommandRequest)

RemoteControlCommandResponse = _reflection.GeneratedProtocolMessageType('RemoteControlCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOTECONTROLCOMMANDRESPONSE,
  __module__ = 'locker_pb2'
  # @@protoc_insertion_point(class_scope:wireless_android_skyjam.RemoteControlCommandResponse)
  ))
_sym_db.RegisterMessage(RemoteControlCommandResponse)


# @@protoc_insertion_point(module_scope)
